// Code generated by protoc-gen-gogo. DO NOT EDIT.
// source: compactorscheduler.proto

package compactorschedulerpb

import (
	bytes "bytes"
	context "context"
	fmt "fmt"
	_ "github.com/gogo/protobuf/gogoproto"
	proto "github.com/gogo/protobuf/proto"
	grpc "google.golang.org/grpc"
	codes "google.golang.org/grpc/codes"
	status "google.golang.org/grpc/status"
	io "io"
	math "math"
	math_bits "math/bits"
	reflect "reflect"
	strconv "strconv"
	strings "strings"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.GoGoProtoPackageIsVersion3 // please upgrade the proto package

type JobType int32

const (
	JOB_TYPE_UNKNOWN    JobType = 0
	JOB_TYPE_COMPACTION JobType = 1
	JOB_TYPE_PLANNING   JobType = 2
)

var JobType_name = map[int32]string{
	0: "JOB_TYPE_UNKNOWN",
	1: "JOB_TYPE_COMPACTION",
	2: "JOB_TYPE_PLANNING",
}

var JobType_value = map[string]int32{
	"JOB_TYPE_UNKNOWN":    0,
	"JOB_TYPE_COMPACTION": 1,
	"JOB_TYPE_PLANNING":   2,
}

func (JobType) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_cc7d2e2996592602, []int{0}
}

type UpdateType int32

const (
	UPDATE_TYPE_UNKNOWN     UpdateType = 0
	UPDATE_TYPE_IN_PROGRESS UpdateType = 1
	UPDATE_TYPE_COMPLETE    UpdateType = 2
	UPDATE_TYPE_REASSIGN    UpdateType = 3
	UPDATE_TYPE_ABANDON     UpdateType = 4
)

var UpdateType_name = map[int32]string{
	0: "UPDATE_TYPE_UNKNOWN",
	1: "UPDATE_TYPE_IN_PROGRESS",
	2: "UPDATE_TYPE_COMPLETE",
	3: "UPDATE_TYPE_REASSIGN",
	4: "UPDATE_TYPE_ABANDON",
}

var UpdateType_value = map[string]int32{
	"UPDATE_TYPE_UNKNOWN":     0,
	"UPDATE_TYPE_IN_PROGRESS": 1,
	"UPDATE_TYPE_COMPLETE":    2,
	"UPDATE_TYPE_REASSIGN":    3,
	"UPDATE_TYPE_ABANDON":     4,
}

func (UpdateType) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_cc7d2e2996592602, []int{1}
}

type StoredJobStatus int32

const (
	STORED_JOB_STATUS_UNKNOWN   StoredJobStatus = 0
	STORED_JOB_STATUS_AVAILABLE StoredJobStatus = 1
	STORED_JOB_STATUS_LEASED    StoredJobStatus = 2
	STORED_JOB_STATUS_COMPLETE  StoredJobStatus = 3
)

var StoredJobStatus_name = map[int32]string{
	0: "STORED_JOB_STATUS_UNKNOWN",
	1: "STORED_JOB_STATUS_AVAILABLE",
	2: "STORED_JOB_STATUS_LEASED",
	3: "STORED_JOB_STATUS_COMPLETE",
}

var StoredJobStatus_value = map[string]int32{
	"STORED_JOB_STATUS_UNKNOWN":   0,
	"STORED_JOB_STATUS_AVAILABLE": 1,
	"STORED_JOB_STATUS_LEASED":    2,
	"STORED_JOB_STATUS_COMPLETE":  3,
}

func (StoredJobStatus) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_cc7d2e2996592602, []int{2}
}

type JobKey struct {
	Id    string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	Epoch int64  `protobuf:"varint,2,opt,name=epoch,proto3" json:"epoch,omitempty"`
}

func (m *JobKey) Reset()      { *m = JobKey{} }
func (*JobKey) ProtoMessage() {}
func (*JobKey) Descriptor() ([]byte, []int) {
	return fileDescriptor_cc7d2e2996592602, []int{0}
}
func (m *JobKey) XXX_Unmarshal(b []byte) error {
	return m.Unmarshal(b)
}
func (m *JobKey) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	if deterministic {
		return xxx_messageInfo_JobKey.Marshal(b, m, deterministic)
	} else {
		b = b[:cap(b)]
		n, err := m.MarshalToSizedBuffer(b)
		if err != nil {
			return nil, err
		}
		return b[:n], nil
	}
}
func (m *JobKey) XXX_Merge(src proto.Message) {
	xxx_messageInfo_JobKey.Merge(m, src)
}
func (m *JobKey) XXX_Size() int {
	return m.Size()
}
func (m *JobKey) XXX_DiscardUnknown() {
	xxx_messageInfo_JobKey.DiscardUnknown(m)
}

var xxx_messageInfo_JobKey proto.InternalMessageInfo

func (m *JobKey) GetId() string {
	if m != nil {
		return m.Id
	}
	return ""
}

func (m *JobKey) GetEpoch() int64 {
	if m != nil {
		return m.Epoch
	}
	return 0
}

type JobSpec struct {
	Tenant  string         `protobuf:"bytes,1,opt,name=tenant,proto3" json:"tenant,omitempty"`
	Job     *CompactionJob `protobuf:"bytes,2,opt,name=job,proto3" json:"job,omitempty"`
	JobType JobType        `protobuf:"varint,3,opt,name=job_type,json=jobType,proto3,enum=compactorschedulerpb.JobType" json:"job_type,omitempty"`
}

func (m *JobSpec) Reset()      { *m = JobSpec{} }
func (*JobSpec) ProtoMessage() {}
func (*JobSpec) Descriptor() ([]byte, []int) {
	return fileDescriptor_cc7d2e2996592602, []int{1}
}
func (m *JobSpec) XXX_Unmarshal(b []byte) error {
	return m.Unmarshal(b)
}
func (m *JobSpec) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	if deterministic {
		return xxx_messageInfo_JobSpec.Marshal(b, m, deterministic)
	} else {
		b = b[:cap(b)]
		n, err := m.MarshalToSizedBuffer(b)
		if err != nil {
			return nil, err
		}
		return b[:n], nil
	}
}
func (m *JobSpec) XXX_Merge(src proto.Message) {
	xxx_messageInfo_JobSpec.Merge(m, src)
}
func (m *JobSpec) XXX_Size() int {
	return m.Size()
}
func (m *JobSpec) XXX_DiscardUnknown() {
	xxx_messageInfo_JobSpec.DiscardUnknown(m)
}

var xxx_messageInfo_JobSpec proto.InternalMessageInfo

func (m *JobSpec) GetTenant() string {
	if m != nil {
		return m.Tenant
	}
	return ""
}

func (m *JobSpec) GetJob() *CompactionJob {
	if m != nil {
		return m.Job
	}
	return nil
}

func (m *JobSpec) GetJobType() JobType {
	if m != nil {
		return m.JobType
	}
	return JOB_TYPE_UNKNOWN
}

type CompactionJob struct {
	BlockIds         [][]byte `protobuf:"bytes,1,rep,name=block_ids,json=blockIds,proto3" json:"block_ids,omitempty"`
	Split            bool     `protobuf:"varint,2,opt,name=split,proto3" json:"split,omitempty"`
	TotalBlocksBytes uint64   `protobuf:"varint,3,opt,name=total_blocks_bytes,json=totalBlocksBytes,proto3" json:"total_blocks_bytes,omitempty"`
}

func (m *CompactionJob) Reset()      { *m = CompactionJob{} }
func (*CompactionJob) ProtoMessage() {}
func (*CompactionJob) Descriptor() ([]byte, []int) {
	return fileDescriptor_cc7d2e2996592602, []int{2}
}
func (m *CompactionJob) XXX_Unmarshal(b []byte) error {
	return m.Unmarshal(b)
}
func (m *CompactionJob) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	if deterministic {
		return xxx_messageInfo_CompactionJob.Marshal(b, m, deterministic)
	} else {
		b = b[:cap(b)]
		n, err := m.MarshalToSizedBuffer(b)
		if err != nil {
			return nil, err
		}
		return b[:n], nil
	}
}
func (m *CompactionJob) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CompactionJob.Merge(m, src)
}
func (m *CompactionJob) XXX_Size() int {
	return m.Size()
}
func (m *CompactionJob) XXX_DiscardUnknown() {
	xxx_messageInfo_CompactionJob.DiscardUnknown(m)
}

var xxx_messageInfo_CompactionJob proto.InternalMessageInfo

func (m *CompactionJob) GetBlockIds() [][]byte {
	if m != nil {
		return m.BlockIds
	}
	return nil
}

func (m *CompactionJob) GetSplit() bool {
	if m != nil {
		return m.Split
	}
	return false
}

func (m *CompactionJob) GetTotalBlocksBytes() uint64 {
	if m != nil {
		return m.TotalBlocksBytes
	}
	return 0
}

type LeaseJobRequest struct {
	WorkerId string `protobuf:"bytes,1,opt,name=worker_id,json=workerId,proto3" json:"worker_id,omitempty"`
}

func (m *LeaseJobRequest) Reset()      { *m = LeaseJobRequest{} }
func (*LeaseJobRequest) ProtoMessage() {}
func (*LeaseJobRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_cc7d2e2996592602, []int{3}
}
func (m *LeaseJobRequest) XXX_Unmarshal(b []byte) error {
	return m.Unmarshal(b)
}
func (m *LeaseJobRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	if deterministic {
		return xxx_messageInfo_LeaseJobRequest.Marshal(b, m, deterministic)
	} else {
		b = b[:cap(b)]
		n, err := m.MarshalToSizedBuffer(b)
		if err != nil {
			return nil, err
		}
		return b[:n], nil
	}
}
func (m *LeaseJobRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_LeaseJobRequest.Merge(m, src)
}
func (m *LeaseJobRequest) XXX_Size() int {
	return m.Size()
}
func (m *LeaseJobRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_LeaseJobRequest.DiscardUnknown(m)
}

var xxx_messageInfo_LeaseJobRequest proto.InternalMessageInfo

func (m *LeaseJobRequest) GetWorkerId() string {
	if m != nil {
		return m.WorkerId
	}
	return ""
}

type LeaseJobResponse struct {
	Key  *JobKey  `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	Spec *JobSpec `protobuf:"bytes,2,opt,name=spec,proto3" json:"spec,omitempty"`
}

func (m *LeaseJobResponse) Reset()      { *m = LeaseJobResponse{} }
func (*LeaseJobResponse) ProtoMessage() {}
func (*LeaseJobResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_cc7d2e2996592602, []int{4}
}
func (m *LeaseJobResponse) XXX_Unmarshal(b []byte) error {
	return m.Unmarshal(b)
}
func (m *LeaseJobResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	if deterministic {
		return xxx_messageInfo_LeaseJobResponse.Marshal(b, m, deterministic)
	} else {
		b = b[:cap(b)]
		n, err := m.MarshalToSizedBuffer(b)
		if err != nil {
			return nil, err
		}
		return b[:n], nil
	}
}
func (m *LeaseJobResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_LeaseJobResponse.Merge(m, src)
}
func (m *LeaseJobResponse) XXX_Size() int {
	return m.Size()
}
func (m *LeaseJobResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_LeaseJobResponse.DiscardUnknown(m)
}

var xxx_messageInfo_LeaseJobResponse proto.InternalMessageInfo

func (m *LeaseJobResponse) GetKey() *JobKey {
	if m != nil {
		return m.Key
	}
	return nil
}

func (m *LeaseJobResponse) GetSpec() *JobSpec {
	if m != nil {
		return m.Spec
	}
	return nil
}

type PlannedCompactionJob struct {
	Id  string         `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	Job *CompactionJob `protobuf:"bytes,2,opt,name=job,proto3" json:"job,omitempty"`
}

func (m *PlannedCompactionJob) Reset()      { *m = PlannedCompactionJob{} }
func (*PlannedCompactionJob) ProtoMessage() {}
func (*PlannedCompactionJob) Descriptor() ([]byte, []int) {
	return fileDescriptor_cc7d2e2996592602, []int{5}
}
func (m *PlannedCompactionJob) XXX_Unmarshal(b []byte) error {
	return m.Unmarshal(b)
}
func (m *PlannedCompactionJob) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	if deterministic {
		return xxx_messageInfo_PlannedCompactionJob.Marshal(b, m, deterministic)
	} else {
		b = b[:cap(b)]
		n, err := m.MarshalToSizedBuffer(b)
		if err != nil {
			return nil, err
		}
		return b[:n], nil
	}
}
func (m *PlannedCompactionJob) XXX_Merge(src proto.Message) {
	xxx_messageInfo_PlannedCompactionJob.Merge(m, src)
}
func (m *PlannedCompactionJob) XXX_Size() int {
	return m.Size()
}
func (m *PlannedCompactionJob) XXX_DiscardUnknown() {
	xxx_messageInfo_PlannedCompactionJob.DiscardUnknown(m)
}

var xxx_messageInfo_PlannedCompactionJob proto.InternalMessageInfo

func (m *PlannedCompactionJob) GetId() string {
	if m != nil {
		return m.Id
	}
	return ""
}

func (m *PlannedCompactionJob) GetJob() *CompactionJob {
	if m != nil {
		return m.Job
	}
	return nil
}

type PlannedJobsRequest struct {
	Key    *JobKey                 `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	Tenant string                  `protobuf:"bytes,2,opt,name=tenant,proto3" json:"tenant,omitempty"`
	Jobs   []*PlannedCompactionJob `protobuf:"bytes,3,rep,name=jobs,proto3" json:"jobs,omitempty"`
}

func (m *PlannedJobsRequest) Reset()      { *m = PlannedJobsRequest{} }
func (*PlannedJobsRequest) ProtoMessage() {}
func (*PlannedJobsRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_cc7d2e2996592602, []int{6}
}
func (m *PlannedJobsRequest) XXX_Unmarshal(b []byte) error {
	return m.Unmarshal(b)
}
func (m *PlannedJobsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	if deterministic {
		return xxx_messageInfo_PlannedJobsRequest.Marshal(b, m, deterministic)
	} else {
		b = b[:cap(b)]
		n, err := m.MarshalToSizedBuffer(b)
		if err != nil {
			return nil, err
		}
		return b[:n], nil
	}
}
func (m *PlannedJobsRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_PlannedJobsRequest.Merge(m, src)
}
func (m *PlannedJobsRequest) XXX_Size() int {
	return m.Size()
}
func (m *PlannedJobsRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_PlannedJobsRequest.DiscardUnknown(m)
}

var xxx_messageInfo_PlannedJobsRequest proto.InternalMessageInfo

func (m *PlannedJobsRequest) GetKey() *JobKey {
	if m != nil {
		return m.Key
	}
	return nil
}

func (m *PlannedJobsRequest) GetTenant() string {
	if m != nil {
		return m.Tenant
	}
	return ""
}

func (m *PlannedJobsRequest) GetJobs() []*PlannedCompactionJob {
	if m != nil {
		return m.Jobs
	}
	return nil
}

type PlannedJobsResponse struct {
}

func (m *PlannedJobsResponse) Reset()      { *m = PlannedJobsResponse{} }
func (*PlannedJobsResponse) ProtoMessage() {}
func (*PlannedJobsResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_cc7d2e2996592602, []int{7}
}
func (m *PlannedJobsResponse) XXX_Unmarshal(b []byte) error {
	return m.Unmarshal(b)
}
func (m *PlannedJobsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	if deterministic {
		return xxx_messageInfo_PlannedJobsResponse.Marshal(b, m, deterministic)
	} else {
		b = b[:cap(b)]
		n, err := m.MarshalToSizedBuffer(b)
		if err != nil {
			return nil, err
		}
		return b[:n], nil
	}
}
func (m *PlannedJobsResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_PlannedJobsResponse.Merge(m, src)
}
func (m *PlannedJobsResponse) XXX_Size() int {
	return m.Size()
}
func (m *PlannedJobsResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_PlannedJobsResponse.DiscardUnknown(m)
}

var xxx_messageInfo_PlannedJobsResponse proto.InternalMessageInfo

type UpdatePlanJobRequest struct {
	Key    *JobKey    `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	Tenant string     `protobuf:"bytes,2,opt,name=tenant,proto3" json:"tenant,omitempty"`
	Update UpdateType `protobuf:"varint,3,opt,name=update,proto3,enum=compactorschedulerpb.UpdateType" json:"update,omitempty"`
}

func (m *UpdatePlanJobRequest) Reset()      { *m = UpdatePlanJobRequest{} }
func (*UpdatePlanJobRequest) ProtoMessage() {}
func (*UpdatePlanJobRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_cc7d2e2996592602, []int{8}
}
func (m *UpdatePlanJobRequest) XXX_Unmarshal(b []byte) error {
	return m.Unmarshal(b)
}
func (m *UpdatePlanJobRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	if deterministic {
		return xxx_messageInfo_UpdatePlanJobRequest.Marshal(b, m, deterministic)
	} else {
		b = b[:cap(b)]
		n, err := m.MarshalToSizedBuffer(b)
		if err != nil {
			return nil, err
		}
		return b[:n], nil
	}
}
func (m *UpdatePlanJobRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_UpdatePlanJobRequest.Merge(m, src)
}
func (m *UpdatePlanJobRequest) XXX_Size() int {
	return m.Size()
}
func (m *UpdatePlanJobRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_UpdatePlanJobRequest.DiscardUnknown(m)
}

var xxx_messageInfo_UpdatePlanJobRequest proto.InternalMessageInfo

func (m *UpdatePlanJobRequest) GetKey() *JobKey {
	if m != nil {
		return m.Key
	}
	return nil
}

func (m *UpdatePlanJobRequest) GetTenant() string {
	if m != nil {
		return m.Tenant
	}
	return ""
}

func (m *UpdatePlanJobRequest) GetUpdate() UpdateType {
	if m != nil {
		return m.Update
	}
	return UPDATE_TYPE_UNKNOWN
}

type UpdateCompactionJobRequest struct {
	Key    *JobKey    `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	Tenant string     `protobuf:"bytes,2,opt,name=tenant,proto3" json:"tenant,omitempty"`
	Update UpdateType `protobuf:"varint,3,opt,name=update,proto3,enum=compactorschedulerpb.UpdateType" json:"update,omitempty"`
}

func (m *UpdateCompactionJobRequest) Reset()      { *m = UpdateCompactionJobRequest{} }
func (*UpdateCompactionJobRequest) ProtoMessage() {}
func (*UpdateCompactionJobRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_cc7d2e2996592602, []int{9}
}
func (m *UpdateCompactionJobRequest) XXX_Unmarshal(b []byte) error {
	return m.Unmarshal(b)
}
func (m *UpdateCompactionJobRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	if deterministic {
		return xxx_messageInfo_UpdateCompactionJobRequest.Marshal(b, m, deterministic)
	} else {
		b = b[:cap(b)]
		n, err := m.MarshalToSizedBuffer(b)
		if err != nil {
			return nil, err
		}
		return b[:n], nil
	}
}
func (m *UpdateCompactionJobRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_UpdateCompactionJobRequest.Merge(m, src)
}
func (m *UpdateCompactionJobRequest) XXX_Size() int {
	return m.Size()
}
func (m *UpdateCompactionJobRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_UpdateCompactionJobRequest.DiscardUnknown(m)
}

var xxx_messageInfo_UpdateCompactionJobRequest proto.InternalMessageInfo

func (m *UpdateCompactionJobRequest) GetKey() *JobKey {
	if m != nil {
		return m.Key
	}
	return nil
}

func (m *UpdateCompactionJobRequest) GetTenant() string {
	if m != nil {
		return m.Tenant
	}
	return ""
}

func (m *UpdateCompactionJobRequest) GetUpdate() UpdateType {
	if m != nil {
		return m.Update
	}
	return UPDATE_TYPE_UNKNOWN
}

type UpdateJobResponse struct {
}

func (m *UpdateJobResponse) Reset()      { *m = UpdateJobResponse{} }
func (*UpdateJobResponse) ProtoMessage() {}
func (*UpdateJobResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_cc7d2e2996592602, []int{10}
}
func (m *UpdateJobResponse) XXX_Unmarshal(b []byte) error {
	return m.Unmarshal(b)
}
func (m *UpdateJobResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	if deterministic {
		return xxx_messageInfo_UpdateJobResponse.Marshal(b, m, deterministic)
	} else {
		b = b[:cap(b)]
		n, err := m.MarshalToSizedBuffer(b)
		if err != nil {
			return nil, err
		}
		return b[:n], nil
	}
}
func (m *UpdateJobResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_UpdateJobResponse.Merge(m, src)
}
func (m *UpdateJobResponse) XXX_Size() int {
	return m.Size()
}
func (m *UpdateJobResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_UpdateJobResponse.DiscardUnknown(m)
}

var xxx_messageInfo_UpdateJobResponse proto.InternalMessageInfo

type StoredJobInfo struct {
	CreationTime int64           `protobuf:"varint,1,opt,name=creation_time,json=creationTime,proto3" json:"creation_time,omitempty"`
	Status       StoredJobStatus `protobuf:"varint,2,opt,name=status,proto3,enum=compactorschedulerpb.StoredJobStatus" json:"status,omitempty"`
	StatusTime   int64           `protobuf:"varint,3,opt,name=status_time,json=statusTime,proto3" json:"status_time,omitempty"`
	NumLeases    int32           `protobuf:"varint,4,opt,name=num_leases,json=numLeases,proto3" json:"num_leases,omitempty"`
	Epoch        int64           `protobuf:"varint,5,opt,name=epoch,proto3" json:"epoch,omitempty"`
}

func (m *StoredJobInfo) Reset()      { *m = StoredJobInfo{} }
func (*StoredJobInfo) ProtoMessage() {}
func (*StoredJobInfo) Descriptor() ([]byte, []int) {
	return fileDescriptor_cc7d2e2996592602, []int{11}
}
func (m *StoredJobInfo) XXX_Unmarshal(b []byte) error {
	return m.Unmarshal(b)
}
func (m *StoredJobInfo) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	if deterministic {
		return xxx_messageInfo_StoredJobInfo.Marshal(b, m, deterministic)
	} else {
		b = b[:cap(b)]
		n, err := m.MarshalToSizedBuffer(b)
		if err != nil {
			return nil, err
		}
		return b[:n], nil
	}
}
func (m *StoredJobInfo) XXX_Merge(src proto.Message) {
	xxx_messageInfo_StoredJobInfo.Merge(m, src)
}
func (m *StoredJobInfo) XXX_Size() int {
	return m.Size()
}
func (m *StoredJobInfo) XXX_DiscardUnknown() {
	xxx_messageInfo_StoredJobInfo.DiscardUnknown(m)
}

var xxx_messageInfo_StoredJobInfo proto.InternalMessageInfo

func (m *StoredJobInfo) GetCreationTime() int64 {
	if m != nil {
		return m.CreationTime
	}
	return 0
}

func (m *StoredJobInfo) GetStatus() StoredJobStatus {
	if m != nil {
		return m.Status
	}
	return STORED_JOB_STATUS_UNKNOWN
}

func (m *StoredJobInfo) GetStatusTime() int64 {
	if m != nil {
		return m.StatusTime
	}
	return 0
}

func (m *StoredJobInfo) GetNumLeases() int32 {
	if m != nil {
		return m.NumLeases
	}
	return 0
}

func (m *StoredJobInfo) GetEpoch() int64 {
	if m != nil {
		return m.Epoch
	}
	return 0
}

type StoredCompactionJob struct {
	Info  *StoredJobInfo `protobuf:"bytes,1,opt,name=info,proto3" json:"info,omitempty"`
	Job   *CompactionJob `protobuf:"bytes,2,opt,name=job,proto3" json:"job,omitempty"`
	Order uint32         `protobuf:"varint,3,opt,name=order,proto3" json:"order,omitempty"`
}

func (m *StoredCompactionJob) Reset()      { *m = StoredCompactionJob{} }
func (*StoredCompactionJob) ProtoMessage() {}
func (*StoredCompactionJob) Descriptor() ([]byte, []int) {
	return fileDescriptor_cc7d2e2996592602, []int{12}
}
func (m *StoredCompactionJob) XXX_Unmarshal(b []byte) error {
	return m.Unmarshal(b)
}
func (m *StoredCompactionJob) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	if deterministic {
		return xxx_messageInfo_StoredCompactionJob.Marshal(b, m, deterministic)
	} else {
		b = b[:cap(b)]
		n, err := m.MarshalToSizedBuffer(b)
		if err != nil {
			return nil, err
		}
		return b[:n], nil
	}
}
func (m *StoredCompactionJob) XXX_Merge(src proto.Message) {
	xxx_messageInfo_StoredCompactionJob.Merge(m, src)
}
func (m *StoredCompactionJob) XXX_Size() int {
	return m.Size()
}
func (m *StoredCompactionJob) XXX_DiscardUnknown() {
	xxx_messageInfo_StoredCompactionJob.DiscardUnknown(m)
}

var xxx_messageInfo_StoredCompactionJob proto.InternalMessageInfo

func (m *StoredCompactionJob) GetInfo() *StoredJobInfo {
	if m != nil {
		return m.Info
	}
	return nil
}

func (m *StoredCompactionJob) GetJob() *CompactionJob {
	if m != nil {
		return m.Job
	}
	return nil
}

func (m *StoredCompactionJob) GetOrder() uint32 {
	if m != nil {
		return m.Order
	}
	return 0
}

type PersistenceMetadata struct {
	ShardCount   uint32 `protobuf:"varint,1,opt,name=shard_count,json=shardCount,proto3" json:"shard_count,omitempty"`
	CreationTime int64  `protobuf:"varint,2,opt,name=creation_time,json=creationTime,proto3" json:"creation_time,omitempty"`
}

func (m *PersistenceMetadata) Reset()      { *m = PersistenceMetadata{} }
func (*PersistenceMetadata) ProtoMessage() {}
func (*PersistenceMetadata) Descriptor() ([]byte, []int) {
	return fileDescriptor_cc7d2e2996592602, []int{13}
}
func (m *PersistenceMetadata) XXX_Unmarshal(b []byte) error {
	return m.Unmarshal(b)
}
func (m *PersistenceMetadata) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	if deterministic {
		return xxx_messageInfo_PersistenceMetadata.Marshal(b, m, deterministic)
	} else {
		b = b[:cap(b)]
		n, err := m.MarshalToSizedBuffer(b)
		if err != nil {
			return nil, err
		}
		return b[:n], nil
	}
}
func (m *PersistenceMetadata) XXX_Merge(src proto.Message) {
	xxx_messageInfo_PersistenceMetadata.Merge(m, src)
}
func (m *PersistenceMetadata) XXX_Size() int {
	return m.Size()
}
func (m *PersistenceMetadata) XXX_DiscardUnknown() {
	xxx_messageInfo_PersistenceMetadata.DiscardUnknown(m)
}

var xxx_messageInfo_PersistenceMetadata proto.InternalMessageInfo

func (m *PersistenceMetadata) GetShardCount() uint32 {
	if m != nil {
		return m.ShardCount
	}
	return 0
}

func (m *PersistenceMetadata) GetCreationTime() int64 {
	if m != nil {
		return m.CreationTime
	}
	return 0
}

func init() {
	proto.RegisterEnum("compactorschedulerpb.JobType", JobType_name, JobType_value)
	proto.RegisterEnum("compactorschedulerpb.UpdateType", UpdateType_name, UpdateType_value)
	proto.RegisterEnum("compactorschedulerpb.StoredJobStatus", StoredJobStatus_name, StoredJobStatus_value)
	proto.RegisterType((*JobKey)(nil), "compactorschedulerpb.JobKey")
	proto.RegisterType((*JobSpec)(nil), "compactorschedulerpb.JobSpec")
	proto.RegisterType((*CompactionJob)(nil), "compactorschedulerpb.CompactionJob")
	proto.RegisterType((*LeaseJobRequest)(nil), "compactorschedulerpb.LeaseJobRequest")
	proto.RegisterType((*LeaseJobResponse)(nil), "compactorschedulerpb.LeaseJobResponse")
	proto.RegisterType((*PlannedCompactionJob)(nil), "compactorschedulerpb.PlannedCompactionJob")
	proto.RegisterType((*PlannedJobsRequest)(nil), "compactorschedulerpb.PlannedJobsRequest")
	proto.RegisterType((*PlannedJobsResponse)(nil), "compactorschedulerpb.PlannedJobsResponse")
	proto.RegisterType((*UpdatePlanJobRequest)(nil), "compactorschedulerpb.UpdatePlanJobRequest")
	proto.RegisterType((*UpdateCompactionJobRequest)(nil), "compactorschedulerpb.UpdateCompactionJobRequest")
	proto.RegisterType((*UpdateJobResponse)(nil), "compactorschedulerpb.UpdateJobResponse")
	proto.RegisterType((*StoredJobInfo)(nil), "compactorschedulerpb.StoredJobInfo")
	proto.RegisterType((*StoredCompactionJob)(nil), "compactorschedulerpb.StoredCompactionJob")
	proto.RegisterType((*PersistenceMetadata)(nil), "compactorschedulerpb.PersistenceMetadata")
}

func init() { proto.RegisterFile("compactorscheduler.proto", fileDescriptor_cc7d2e2996592602) }

var fileDescriptor_cc7d2e2996592602 = []byte{
	// 982 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xcc, 0x56, 0x4f, 0x6f, 0xe3, 0x44,
	0x14, 0xcf, 0xc4, 0x69, 0xb7, 0x7d, 0xdd, 0x74, 0xbd, 0x93, 0x2c, 0x1b, 0xd2, 0xad, 0x37, 0x72,
	0x05, 0x84, 0x0a, 0x05, 0x08, 0x42, 0xec, 0x05, 0x24, 0x27, 0xb5, 0xaa, 0xa4, 0x59, 0x27, 0x1a,
	0xa7, 0xa0, 0x05, 0x21, 0xcb, 0x7f, 0x66, 0xb7, 0x69, 0x13, 0x8f, 0xb1, 0x1d, 0xa1, 0xdc, 0xf8,
	0x06, 0x20, 0x4e, 0x48, 0x20, 0xce, 0x48, 0x7c, 0x11, 0xb8, 0xf5, 0xb8, 0x47, 0x9a, 0x5e, 0x38,
	0xee, 0x47, 0x40, 0x1e, 0x3b, 0x69, 0xfe, 0xb5, 0xbb, 0xac, 0x38, 0x70, 0xf3, 0xbc, 0xf7, 0x7b,
	0xef, 0xfd, 0xde, 0x9f, 0x79, 0x63, 0x28, 0xd8, 0x6c, 0xe0, 0x99, 0x76, 0xc8, 0xfc, 0xc0, 0x3e,
	0xa1, 0xce, 0xb0, 0x4f, 0xfd, 0x8a, 0xe7, 0xb3, 0x90, 0xe1, 0xfc, 0xb2, 0xc6, 0xb3, 0x8a, 0xf9,
	0x67, 0xec, 0x19, 0xe3, 0x80, 0xf7, 0xa3, 0xaf, 0x18, 0x2b, 0x57, 0x60, 0xbd, 0xc9, 0xac, 0x23,
	0x3a, 0xc2, 0xdb, 0x90, 0xee, 0x39, 0x05, 0x54, 0x42, 0xe5, 0x4d, 0x92, 0xee, 0x39, 0x38, 0x0f,
	0x6b, 0xd4, 0x63, 0xf6, 0x49, 0x21, 0x5d, 0x42, 0x65, 0x81, 0xc4, 0x07, 0xf9, 0x47, 0x04, 0xb7,
	0x9a, 0xcc, 0xd2, 0x3d, 0x6a, 0xe3, 0x37, 0x60, 0x3d, 0xa4, 0xae, 0xe9, 0x86, 0x89, 0x55, 0x72,
	0xc2, 0x1f, 0x83, 0x70, 0xca, 0x2c, 0x6e, 0xb7, 0x55, 0xdd, 0xab, 0xac, 0x62, 0x53, 0xa9, 0xc7,
	0xc2, 0x1e, 0x73, 0x9b, 0xcc, 0x22, 0x11, 0x1e, 0x3f, 0x82, 0x8d, 0x53, 0x66, 0x19, 0xe1, 0xc8,
	0xa3, 0x05, 0xa1, 0x84, 0xca, 0xdb, 0xd5, 0xdd, 0xd5, 0xb6, 0x4d, 0x66, 0x75, 0x47, 0x1e, 0x25,
	0xb7, 0x4e, 0xe3, 0x0f, 0xd9, 0x83, 0xec, 0x9c, 0x3f, 0xbc, 0x03, 0x9b, 0x56, 0x9f, 0xd9, 0x67,
	0x46, 0xcf, 0x09, 0x0a, 0xa8, 0x24, 0x94, 0x6f, 0x93, 0x0d, 0x2e, 0x68, 0x38, 0x41, 0x94, 0x58,
	0xe0, 0xf5, 0x7b, 0x21, 0x27, 0xb8, 0x41, 0xe2, 0x03, 0x7e, 0x0f, 0x70, 0xc8, 0x42, 0xb3, 0x6f,
	0x70, 0x5c, 0x60, 0x58, 0xa3, 0x90, 0x06, 0x9c, 0x47, 0x86, 0x88, 0x5c, 0x53, 0xe3, 0x8a, 0x5a,
	0x24, 0x97, 0x2b, 0x70, 0xa7, 0x45, 0xcd, 0x80, 0x46, 0xe4, 0xe9, 0x37, 0x43, 0x1a, 0x84, 0x51,
	0xcc, 0x6f, 0x99, 0x7f, 0x46, 0x7d, 0x63, 0x5a, 0xc6, 0x8d, 0x58, 0xd0, 0x70, 0xe4, 0x21, 0x88,
	0x57, 0xf8, 0xc0, 0x63, 0x6e, 0x40, 0x71, 0x05, 0x84, 0x33, 0x3a, 0xe2, 0xd0, 0xad, 0xea, 0x83,
	0x6b, 0x53, 0x3d, 0xa2, 0x23, 0x12, 0x01, 0xf1, 0x87, 0x90, 0x09, 0x3c, 0x6a, 0x27, 0x75, 0xbd,
	0xbe, 0x36, 0x51, 0x6f, 0x08, 0x87, 0xca, 0x5f, 0x43, 0xbe, 0xd3, 0x37, 0x5d, 0x97, 0x3a, 0xf3,
	0xf5, 0x59, 0xec, 0xf5, 0xeb, 0x75, 0x4c, 0xfe, 0x05, 0x01, 0x4e, 0xfc, 0x37, 0x99, 0x15, 0x4c,
	0x2a, 0xf1, 0x6f, 0x13, 0xbb, 0x9a, 0xa3, 0xf4, 0xdc, 0x1c, 0x7d, 0x06, 0x99, 0x53, 0x66, 0x45,
	0x4d, 0x10, 0xca, 0x5b, 0xd5, 0xfd, 0xd5, 0x8e, 0x56, 0xe5, 0x47, 0xb8, 0x9d, 0x7c, 0x0f, 0x72,
	0x73, 0xec, 0xe2, 0xba, 0xcb, 0x3f, 0x21, 0xc8, 0x1f, 0x7b, 0x8e, 0x19, 0xd2, 0x48, 0x3b, 0xd3,
	0xc1, 0xff, 0x8a, 0xf7, 0x23, 0x58, 0x1f, 0x72, 0xff, 0xc9, 0x18, 0x97, 0x56, 0xbb, 0x8a, 0x39,
	0xf0, 0x49, 0x4e, 0xf0, 0xf2, 0xaf, 0x08, 0x8a, 0xb1, 0x78, 0x3e, 0x9f, 0xff, 0x0d, 0xc1, 0x1c,
	0xdc, 0x8d, 0xa5, 0x33, 0x83, 0x2c, 0xff, 0x89, 0x20, 0xab, 0x87, 0xcc, 0xe7, 0x75, 0x6e, 0xb8,
	0x4f, 0x19, 0xde, 0x83, 0xac, 0xed, 0x53, 0x33, 0xa2, 0x6f, 0x84, 0xbd, 0x01, 0xe5, 0x94, 0x05,
	0x72, 0x7b, 0x22, 0xec, 0xf6, 0x06, 0x14, 0x7f, 0x0a, 0xeb, 0x41, 0x68, 0x86, 0xc3, 0x80, 0xb3,
	0xdb, 0xae, 0xbe, 0xb5, 0x9a, 0xc5, 0xd4, 0xb3, 0xce, 0xc1, 0x24, 0x31, 0xc2, 0x0f, 0x61, 0x2b,
	0xfe, 0x8a, 0x23, 0x08, 0x3c, 0x02, 0xc4, 0x22, 0xee, 0x7f, 0x17, 0xc0, 0x1d, 0x0e, 0x8c, 0x7e,
	0x74, 0xef, 0x82, 0x42, 0xa6, 0x84, 0xca, 0x6b, 0x64, 0xd3, 0x1d, 0x0e, 0xf8, 0x45, 0x0c, 0xae,
	0xf6, 0xdb, 0xda, 0xec, 0x7e, 0xfb, 0x19, 0x41, 0x2e, 0x8e, 0x38, 0x7f, 0x63, 0x3e, 0x81, 0x4c,
	0xcf, 0x7d, 0xca, 0x92, 0xda, 0xef, 0xbd, 0x84, 0x6a, 0x54, 0x04, 0xc2, 0x0d, 0x5e, 0x77, 0x19,
	0xe6, 0x61, 0x8d, 0xf9, 0x0e, 0xf5, 0x79, 0x5e, 0x59, 0x12, 0x1f, 0xe4, 0xaf, 0x20, 0xd7, 0xa1,
	0x7e, 0xd0, 0x0b, 0x42, 0xea, 0xda, 0xf4, 0x31, 0x0d, 0x4d, 0xc7, 0x0c, 0x4d, 0x5e, 0x8a, 0x13,
	0xd3, 0x77, 0x0c, 0x9b, 0x0d, 0x93, 0x6d, 0x9c, 0x25, 0xc0, 0x45, 0xf5, 0x48, 0xb2, 0xdc, 0x8f,
	0xf4, 0x72, 0x3f, 0xf6, 0xdb, 0x7c, 0xb3, 0x47, 0xed, 0xc6, 0x79, 0x10, 0x9b, 0xed, 0x9a, 0xd1,
	0x7d, 0xd2, 0x51, 0x8d, 0x63, 0xed, 0x48, 0x6b, 0x7f, 0xa1, 0x89, 0x29, 0x7c, 0x1f, 0x72, 0x53,
	0x69, 0xbd, 0xfd, 0xb8, 0xa3, 0xd4, 0xbb, 0x8d, 0xb6, 0x26, 0x22, 0x7c, 0x0f, 0xee, 0x4e, 0x15,
	0x9d, 0x96, 0xa2, 0x69, 0x0d, 0xed, 0x50, 0x4c, 0xef, 0x7f, 0x8f, 0x00, 0xae, 0x66, 0x28, 0x32,
	0x3f, 0xee, 0x1c, 0x28, 0x5d, 0x75, 0xd1, 0xef, 0x0e, 0xdc, 0x9f, 0x55, 0x34, 0x34, 0xa3, 0x43,
	0xda, 0x87, 0x44, 0xd5, 0x75, 0x11, 0xe1, 0x02, 0xe4, 0x67, 0x95, 0x51, 0xdc, 0x96, 0xda, 0x55,
	0xc5, 0xf4, 0xa2, 0x86, 0xa8, 0x8a, 0xae, 0x37, 0x0e, 0x35, 0x51, 0x58, 0x8c, 0xa4, 0xd4, 0x14,
	0xed, 0xa0, 0xad, 0x89, 0x99, 0x88, 0xd1, 0x9d, 0x85, 0x79, 0xc2, 0xbb, 0xf0, 0xa6, 0xde, 0x6d,
	0x13, 0xf5, 0xc0, 0x88, 0x72, 0xd0, 0xbb, 0x4a, 0xf7, 0x58, 0x9f, 0x21, 0xf7, 0x10, 0x76, 0x96,
	0xd5, 0xca, 0xe7, 0x4a, 0xa3, 0xa5, 0xd4, 0x5a, 0xaa, 0x88, 0xf0, 0x03, 0x28, 0x2c, 0x03, 0x5a,
	0xaa, 0xa2, 0xab, 0x07, 0x62, 0x1a, 0x4b, 0x50, 0x5c, 0xd6, 0x4e, 0x93, 0x10, 0xaa, 0xbf, 0x0b,
	0x80, 0xeb, 0x93, 0x99, 0xd0, 0x27, 0x33, 0x81, 0x9f, 0xc0, 0xc6, 0xe4, 0xbd, 0xc0, 0xd7, 0xdc,
	0x8b, 0x85, 0xf7, 0xa7, 0xf8, 0xf6, 0xcb, 0x60, 0xc9, 0xb3, 0x63, 0xc1, 0xd6, 0xcc, 0x56, 0xc4,
	0xe5, 0x1b, 0xd7, 0xea, 0xcc, 0x5a, 0x2f, 0xbe, 0xfb, 0x0a, 0xc8, 0x24, 0x86, 0x03, 0xd9, 0xb9,
	0x0d, 0x8b, 0xf7, 0x6f, 0xda, 0x30, 0xf3, 0x6b, 0xb8, 0xf8, 0xce, 0x4d, 0xd8, 0xd9, 0x4c, 0x3c,
	0xc8, 0xad, 0x58, 0x96, 0xf8, 0x83, 0x9b, 0xec, 0x57, 0xed, 0xd5, 0x57, 0x8e, 0x58, 0x6b, 0x9e,
	0x5f, 0x48, 0xa9, 0xe7, 0x17, 0x52, 0xea, 0xc5, 0x85, 0x84, 0xbe, 0x1b, 0x4b, 0xe8, 0xb7, 0xb1,
	0x84, 0xfe, 0x18, 0x4b, 0xe8, 0x7c, 0x2c, 0xa1, 0xbf, 0xc6, 0x12, 0xfa, 0x7b, 0x2c, 0xa5, 0x5e,
	0x8c, 0x25, 0xf4, 0xc3, 0xa5, 0x94, 0x3a, 0xbf, 0x94, 0x52, 0xcf, 0x2f, 0xa5, 0xd4, 0x97, 0x2b,
	0xff, 0xc7, 0xac, 0x75, 0xfe, 0x03, 0xf6, 0xd1, 0x3f, 0x01, 0x00, 0x00, 0xff, 0xff, 0x79, 0x5b,
	0x85, 0x60, 0xc8, 0x09, 0x00, 0x00,
}

func (x JobType) String() string {
	s, ok := JobType_name[int32(x)]
	if ok {
		return s
	}
	return strconv.Itoa(int(x))
}
func (x UpdateType) String() string {
	s, ok := UpdateType_name[int32(x)]
	if ok {
		return s
	}
	return strconv.Itoa(int(x))
}
func (x StoredJobStatus) String() string {
	s, ok := StoredJobStatus_name[int32(x)]
	if ok {
		return s
	}
	return strconv.Itoa(int(x))
}
func (this *JobKey) Equal(that interface{}) bool {
	if that == nil {
		return this == nil
	}

	that1, ok := that.(*JobKey)
	if !ok {
		that2, ok := that.(JobKey)
		if ok {
			that1 = &that2
		} else {
			return false
		}
	}
	if that1 == nil {
		return this == nil
	} else if this == nil {
		return false
	}
	if this.Id != that1.Id {
		return false
	}
	if this.Epoch != that1.Epoch {
		return false
	}
	return true
}
func (this *JobSpec) Equal(that interface{}) bool {
	if that == nil {
		return this == nil
	}

	that1, ok := that.(*JobSpec)
	if !ok {
		that2, ok := that.(JobSpec)
		if ok {
			that1 = &that2
		} else {
			return false
		}
	}
	if that1 == nil {
		return this == nil
	} else if this == nil {
		return false
	}
	if this.Tenant != that1.Tenant {
		return false
	}
	if !this.Job.Equal(that1.Job) {
		return false
	}
	if this.JobType != that1.JobType {
		return false
	}
	return true
}
func (this *CompactionJob) Equal(that interface{}) bool {
	if that == nil {
		return this == nil
	}

	that1, ok := that.(*CompactionJob)
	if !ok {
		that2, ok := that.(CompactionJob)
		if ok {
			that1 = &that2
		} else {
			return false
		}
	}
	if that1 == nil {
		return this == nil
	} else if this == nil {
		return false
	}
	if len(this.BlockIds) != len(that1.BlockIds) {
		return false
	}
	for i := range this.BlockIds {
		if !bytes.Equal(this.BlockIds[i], that1.BlockIds[i]) {
			return false
		}
	}
	if this.Split != that1.Split {
		return false
	}
	if this.TotalBlocksBytes != that1.TotalBlocksBytes {
		return false
	}
	return true
}
func (this *LeaseJobRequest) Equal(that interface{}) bool {
	if that == nil {
		return this == nil
	}

	that1, ok := that.(*LeaseJobRequest)
	if !ok {
		that2, ok := that.(LeaseJobRequest)
		if ok {
			that1 = &that2
		} else {
			return false
		}
	}
	if that1 == nil {
		return this == nil
	} else if this == nil {
		return false
	}
	if this.WorkerId != that1.WorkerId {
		return false
	}
	return true
}
func (this *LeaseJobResponse) Equal(that interface{}) bool {
	if that == nil {
		return this == nil
	}

	that1, ok := that.(*LeaseJobResponse)
	if !ok {
		that2, ok := that.(LeaseJobResponse)
		if ok {
			that1 = &that2
		} else {
			return false
		}
	}
	if that1 == nil {
		return this == nil
	} else if this == nil {
		return false
	}
	if !this.Key.Equal(that1.Key) {
		return false
	}
	if !this.Spec.Equal(that1.Spec) {
		return false
	}
	return true
}
func (this *PlannedCompactionJob) Equal(that interface{}) bool {
	if that == nil {
		return this == nil
	}

	that1, ok := that.(*PlannedCompactionJob)
	if !ok {
		that2, ok := that.(PlannedCompactionJob)
		if ok {
			that1 = &that2
		} else {
			return false
		}
	}
	if that1 == nil {
		return this == nil
	} else if this == nil {
		return false
	}
	if this.Id != that1.Id {
		return false
	}
	if !this.Job.Equal(that1.Job) {
		return false
	}
	return true
}
func (this *PlannedJobsRequest) Equal(that interface{}) bool {
	if that == nil {
		return this == nil
	}

	that1, ok := that.(*PlannedJobsRequest)
	if !ok {
		that2, ok := that.(PlannedJobsRequest)
		if ok {
			that1 = &that2
		} else {
			return false
		}
	}
	if that1 == nil {
		return this == nil
	} else if this == nil {
		return false
	}
	if !this.Key.Equal(that1.Key) {
		return false
	}
	if this.Tenant != that1.Tenant {
		return false
	}
	if len(this.Jobs) != len(that1.Jobs) {
		return false
	}
	for i := range this.Jobs {
		if !this.Jobs[i].Equal(that1.Jobs[i]) {
			return false
		}
	}
	return true
}
func (this *PlannedJobsResponse) Equal(that interface{}) bool {
	if that == nil {
		return this == nil
	}

	that1, ok := that.(*PlannedJobsResponse)
	if !ok {
		that2, ok := that.(PlannedJobsResponse)
		if ok {
			that1 = &that2
		} else {
			return false
		}
	}
	if that1 == nil {
		return this == nil
	} else if this == nil {
		return false
	}
	return true
}
func (this *UpdatePlanJobRequest) Equal(that interface{}) bool {
	if that == nil {
		return this == nil
	}

	that1, ok := that.(*UpdatePlanJobRequest)
	if !ok {
		that2, ok := that.(UpdatePlanJobRequest)
		if ok {
			that1 = &that2
		} else {
			return false
		}
	}
	if that1 == nil {
		return this == nil
	} else if this == nil {
		return false
	}
	if !this.Key.Equal(that1.Key) {
		return false
	}
	if this.Tenant != that1.Tenant {
		return false
	}
	if this.Update != that1.Update {
		return false
	}
	return true
}
func (this *UpdateCompactionJobRequest) Equal(that interface{}) bool {
	if that == nil {
		return this == nil
	}

	that1, ok := that.(*UpdateCompactionJobRequest)
	if !ok {
		that2, ok := that.(UpdateCompactionJobRequest)
		if ok {
			that1 = &that2
		} else {
			return false
		}
	}
	if that1 == nil {
		return this == nil
	} else if this == nil {
		return false
	}
	if !this.Key.Equal(that1.Key) {
		return false
	}
	if this.Tenant != that1.Tenant {
		return false
	}
	if this.Update != that1.Update {
		return false
	}
	return true
}
func (this *UpdateJobResponse) Equal(that interface{}) bool {
	if that == nil {
		return this == nil
	}

	that1, ok := that.(*UpdateJobResponse)
	if !ok {
		that2, ok := that.(UpdateJobResponse)
		if ok {
			that1 = &that2
		} else {
			return false
		}
	}
	if that1 == nil {
		return this == nil
	} else if this == nil {
		return false
	}
	return true
}
func (this *StoredJobInfo) Equal(that interface{}) bool {
	if that == nil {
		return this == nil
	}

	that1, ok := that.(*StoredJobInfo)
	if !ok {
		that2, ok := that.(StoredJobInfo)
		if ok {
			that1 = &that2
		} else {
			return false
		}
	}
	if that1 == nil {
		return this == nil
	} else if this == nil {
		return false
	}
	if this.CreationTime != that1.CreationTime {
		return false
	}
	if this.Status != that1.Status {
		return false
	}
	if this.StatusTime != that1.StatusTime {
		return false
	}
	if this.NumLeases != that1.NumLeases {
		return false
	}
	if this.Epoch != that1.Epoch {
		return false
	}
	return true
}
func (this *StoredCompactionJob) Equal(that interface{}) bool {
	if that == nil {
		return this == nil
	}

	that1, ok := that.(*StoredCompactionJob)
	if !ok {
		that2, ok := that.(StoredCompactionJob)
		if ok {
			that1 = &that2
		} else {
			return false
		}
	}
	if that1 == nil {
		return this == nil
	} else if this == nil {
		return false
	}
	if !this.Info.Equal(that1.Info) {
		return false
	}
	if !this.Job.Equal(that1.Job) {
		return false
	}
	if this.Order != that1.Order {
		return false
	}
	return true
}
func (this *PersistenceMetadata) Equal(that interface{}) bool {
	if that == nil {
		return this == nil
	}

	that1, ok := that.(*PersistenceMetadata)
	if !ok {
		that2, ok := that.(PersistenceMetadata)
		if ok {
			that1 = &that2
		} else {
			return false
		}
	}
	if that1 == nil {
		return this == nil
	} else if this == nil {
		return false
	}
	if this.ShardCount != that1.ShardCount {
		return false
	}
	if this.CreationTime != that1.CreationTime {
		return false
	}
	return true
}
func (this *JobKey) GoString() string {
	if this == nil {
		return "nil"
	}
	s := make([]string, 0, 6)
	s = append(s, "&compactorschedulerpb.JobKey{")
	s = append(s, "Id: "+fmt.Sprintf("%#v", this.Id)+",\n")
	s = append(s, "Epoch: "+fmt.Sprintf("%#v", this.Epoch)+",\n")
	s = append(s, "}")
	return strings.Join(s, "")
}
func (this *JobSpec) GoString() string {
	if this == nil {
		return "nil"
	}
	s := make([]string, 0, 7)
	s = append(s, "&compactorschedulerpb.JobSpec{")
	s = append(s, "Tenant: "+fmt.Sprintf("%#v", this.Tenant)+",\n")
	if this.Job != nil {
		s = append(s, "Job: "+fmt.Sprintf("%#v", this.Job)+",\n")
	}
	s = append(s, "JobType: "+fmt.Sprintf("%#v", this.JobType)+",\n")
	s = append(s, "}")
	return strings.Join(s, "")
}
func (this *CompactionJob) GoString() string {
	if this == nil {
		return "nil"
	}
	s := make([]string, 0, 7)
	s = append(s, "&compactorschedulerpb.CompactionJob{")
	s = append(s, "BlockIds: "+fmt.Sprintf("%#v", this.BlockIds)+",\n")
	s = append(s, "Split: "+fmt.Sprintf("%#v", this.Split)+",\n")
	s = append(s, "TotalBlocksBytes: "+fmt.Sprintf("%#v", this.TotalBlocksBytes)+",\n")
	s = append(s, "}")
	return strings.Join(s, "")
}
func (this *LeaseJobRequest) GoString() string {
	if this == nil {
		return "nil"
	}
	s := make([]string, 0, 5)
	s = append(s, "&compactorschedulerpb.LeaseJobRequest{")
	s = append(s, "WorkerId: "+fmt.Sprintf("%#v", this.WorkerId)+",\n")
	s = append(s, "}")
	return strings.Join(s, "")
}
func (this *LeaseJobResponse) GoString() string {
	if this == nil {
		return "nil"
	}
	s := make([]string, 0, 6)
	s = append(s, "&compactorschedulerpb.LeaseJobResponse{")
	if this.Key != nil {
		s = append(s, "Key: "+fmt.Sprintf("%#v", this.Key)+",\n")
	}
	if this.Spec != nil {
		s = append(s, "Spec: "+fmt.Sprintf("%#v", this.Spec)+",\n")
	}
	s = append(s, "}")
	return strings.Join(s, "")
}
func (this *PlannedCompactionJob) GoString() string {
	if this == nil {
		return "nil"
	}
	s := make([]string, 0, 6)
	s = append(s, "&compactorschedulerpb.PlannedCompactionJob{")
	s = append(s, "Id: "+fmt.Sprintf("%#v", this.Id)+",\n")
	if this.Job != nil {
		s = append(s, "Job: "+fmt.Sprintf("%#v", this.Job)+",\n")
	}
	s = append(s, "}")
	return strings.Join(s, "")
}
func (this *PlannedJobsRequest) GoString() string {
	if this == nil {
		return "nil"
	}
	s := make([]string, 0, 7)
	s = append(s, "&compactorschedulerpb.PlannedJobsRequest{")
	if this.Key != nil {
		s = append(s, "Key: "+fmt.Sprintf("%#v", this.Key)+",\n")
	}
	s = append(s, "Tenant: "+fmt.Sprintf("%#v", this.Tenant)+",\n")
	if this.Jobs != nil {
		s = append(s, "Jobs: "+fmt.Sprintf("%#v", this.Jobs)+",\n")
	}
	s = append(s, "}")
	return strings.Join(s, "")
}
func (this *PlannedJobsResponse) GoString() string {
	if this == nil {
		return "nil"
	}
	s := make([]string, 0, 4)
	s = append(s, "&compactorschedulerpb.PlannedJobsResponse{")
	s = append(s, "}")
	return strings.Join(s, "")
}
func (this *UpdatePlanJobRequest) GoString() string {
	if this == nil {
		return "nil"
	}
	s := make([]string, 0, 7)
	s = append(s, "&compactorschedulerpb.UpdatePlanJobRequest{")
	if this.Key != nil {
		s = append(s, "Key: "+fmt.Sprintf("%#v", this.Key)+",\n")
	}
	s = append(s, "Tenant: "+fmt.Sprintf("%#v", this.Tenant)+",\n")
	s = append(s, "Update: "+fmt.Sprintf("%#v", this.Update)+",\n")
	s = append(s, "}")
	return strings.Join(s, "")
}
func (this *UpdateCompactionJobRequest) GoString() string {
	if this == nil {
		return "nil"
	}
	s := make([]string, 0, 7)
	s = append(s, "&compactorschedulerpb.UpdateCompactionJobRequest{")
	if this.Key != nil {
		s = append(s, "Key: "+fmt.Sprintf("%#v", this.Key)+",\n")
	}
	s = append(s, "Tenant: "+fmt.Sprintf("%#v", this.Tenant)+",\n")
	s = append(s, "Update: "+fmt.Sprintf("%#v", this.Update)+",\n")
	s = append(s, "}")
	return strings.Join(s, "")
}
func (this *UpdateJobResponse) GoString() string {
	if this == nil {
		return "nil"
	}
	s := make([]string, 0, 4)
	s = append(s, "&compactorschedulerpb.UpdateJobResponse{")
	s = append(s, "}")
	return strings.Join(s, "")
}
func (this *StoredJobInfo) GoString() string {
	if this == nil {
		return "nil"
	}
	s := make([]string, 0, 9)
	s = append(s, "&compactorschedulerpb.StoredJobInfo{")
	s = append(s, "CreationTime: "+fmt.Sprintf("%#v", this.CreationTime)+",\n")
	s = append(s, "Status: "+fmt.Sprintf("%#v", this.Status)+",\n")
	s = append(s, "StatusTime: "+fmt.Sprintf("%#v", this.StatusTime)+",\n")
	s = append(s, "NumLeases: "+fmt.Sprintf("%#v", this.NumLeases)+",\n")
	s = append(s, "Epoch: "+fmt.Sprintf("%#v", this.Epoch)+",\n")
	s = append(s, "}")
	return strings.Join(s, "")
}
func (this *StoredCompactionJob) GoString() string {
	if this == nil {
		return "nil"
	}
	s := make([]string, 0, 7)
	s = append(s, "&compactorschedulerpb.StoredCompactionJob{")
	if this.Info != nil {
		s = append(s, "Info: "+fmt.Sprintf("%#v", this.Info)+",\n")
	}
	if this.Job != nil {
		s = append(s, "Job: "+fmt.Sprintf("%#v", this.Job)+",\n")
	}
	s = append(s, "Order: "+fmt.Sprintf("%#v", this.Order)+",\n")
	s = append(s, "}")
	return strings.Join(s, "")
}
func (this *PersistenceMetadata) GoString() string {
	if this == nil {
		return "nil"
	}
	s := make([]string, 0, 6)
	s = append(s, "&compactorschedulerpb.PersistenceMetadata{")
	s = append(s, "ShardCount: "+fmt.Sprintf("%#v", this.ShardCount)+",\n")
	s = append(s, "CreationTime: "+fmt.Sprintf("%#v", this.CreationTime)+",\n")
	s = append(s, "}")
	return strings.Join(s, "")
}
func valueToGoStringCompactorscheduler(v interface{}, typ string) string {
	rv := reflect.ValueOf(v)
	if rv.IsNil() {
		return "nil"
	}
	pv := reflect.Indirect(rv).Interface()
	return fmt.Sprintf("func(v %v) *%v { return &v } ( %#v )", typ, typ, pv)
}

// Reference imports to suppress errors if they are not otherwise used.
var _ context.Context
var _ grpc.ClientConn

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
const _ = grpc.SupportPackageIsVersion4

// CompactorSchedulerClient is the client API for CompactorScheduler service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type CompactorSchedulerClient interface {
	LeaseJob(ctx context.Context, in *LeaseJobRequest, opts ...grpc.CallOption) (*LeaseJobResponse, error)
	PlannedJobs(ctx context.Context, in *PlannedJobsRequest, opts ...grpc.CallOption) (*PlannedJobsResponse, error)
	UpdatePlanJob(ctx context.Context, in *UpdatePlanJobRequest, opts ...grpc.CallOption) (*UpdateJobResponse, error)
	UpdateCompactionJob(ctx context.Context, in *UpdateCompactionJobRequest, opts ...grpc.CallOption) (*UpdateJobResponse, error)
}

type compactorSchedulerClient struct {
	cc *grpc.ClientConn
}

func NewCompactorSchedulerClient(cc *grpc.ClientConn) CompactorSchedulerClient {
	return &compactorSchedulerClient{cc}
}

func (c *compactorSchedulerClient) LeaseJob(ctx context.Context, in *LeaseJobRequest, opts ...grpc.CallOption) (*LeaseJobResponse, error) {
	out := new(LeaseJobResponse)
	err := c.cc.Invoke(ctx, "/compactorschedulerpb.CompactorScheduler/LeaseJob", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *compactorSchedulerClient) PlannedJobs(ctx context.Context, in *PlannedJobsRequest, opts ...grpc.CallOption) (*PlannedJobsResponse, error) {
	out := new(PlannedJobsResponse)
	err := c.cc.Invoke(ctx, "/compactorschedulerpb.CompactorScheduler/PlannedJobs", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *compactorSchedulerClient) UpdatePlanJob(ctx context.Context, in *UpdatePlanJobRequest, opts ...grpc.CallOption) (*UpdateJobResponse, error) {
	out := new(UpdateJobResponse)
	err := c.cc.Invoke(ctx, "/compactorschedulerpb.CompactorScheduler/UpdatePlanJob", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *compactorSchedulerClient) UpdateCompactionJob(ctx context.Context, in *UpdateCompactionJobRequest, opts ...grpc.CallOption) (*UpdateJobResponse, error) {
	out := new(UpdateJobResponse)
	err := c.cc.Invoke(ctx, "/compactorschedulerpb.CompactorScheduler/UpdateCompactionJob", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// CompactorSchedulerServer is the server API for CompactorScheduler service.
type CompactorSchedulerServer interface {
	LeaseJob(context.Context, *LeaseJobRequest) (*LeaseJobResponse, error)
	PlannedJobs(context.Context, *PlannedJobsRequest) (*PlannedJobsResponse, error)
	UpdatePlanJob(context.Context, *UpdatePlanJobRequest) (*UpdateJobResponse, error)
	UpdateCompactionJob(context.Context, *UpdateCompactionJobRequest) (*UpdateJobResponse, error)
}

// UnimplementedCompactorSchedulerServer can be embedded to have forward compatible implementations.
type UnimplementedCompactorSchedulerServer struct {
}

func (*UnimplementedCompactorSchedulerServer) LeaseJob(ctx context.Context, req *LeaseJobRequest) (*LeaseJobResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method LeaseJob not implemented")
}
func (*UnimplementedCompactorSchedulerServer) PlannedJobs(ctx context.Context, req *PlannedJobsRequest) (*PlannedJobsResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method PlannedJobs not implemented")
}
func (*UnimplementedCompactorSchedulerServer) UpdatePlanJob(ctx context.Context, req *UpdatePlanJobRequest) (*UpdateJobResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method UpdatePlanJob not implemented")
}
func (*UnimplementedCompactorSchedulerServer) UpdateCompactionJob(ctx context.Context, req *UpdateCompactionJobRequest) (*UpdateJobResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method UpdateCompactionJob not implemented")
}

func RegisterCompactorSchedulerServer(s *grpc.Server, srv CompactorSchedulerServer) {
	s.RegisterService(&_CompactorScheduler_serviceDesc, srv)
}

func _CompactorScheduler_LeaseJob_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(LeaseJobRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(CompactorSchedulerServer).LeaseJob(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/compactorschedulerpb.CompactorScheduler/LeaseJob",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(CompactorSchedulerServer).LeaseJob(ctx, req.(*LeaseJobRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _CompactorScheduler_PlannedJobs_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(PlannedJobsRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(CompactorSchedulerServer).PlannedJobs(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/compactorschedulerpb.CompactorScheduler/PlannedJobs",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(CompactorSchedulerServer).PlannedJobs(ctx, req.(*PlannedJobsRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _CompactorScheduler_UpdatePlanJob_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(UpdatePlanJobRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(CompactorSchedulerServer).UpdatePlanJob(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/compactorschedulerpb.CompactorScheduler/UpdatePlanJob",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(CompactorSchedulerServer).UpdatePlanJob(ctx, req.(*UpdatePlanJobRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _CompactorScheduler_UpdateCompactionJob_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(UpdateCompactionJobRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(CompactorSchedulerServer).UpdateCompactionJob(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/compactorschedulerpb.CompactorScheduler/UpdateCompactionJob",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(CompactorSchedulerServer).UpdateCompactionJob(ctx, req.(*UpdateCompactionJobRequest))
	}
	return interceptor(ctx, in, info, handler)
}

var _CompactorScheduler_serviceDesc = grpc.ServiceDesc{
	ServiceName: "compactorschedulerpb.CompactorScheduler",
	HandlerType: (*CompactorSchedulerServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "LeaseJob",
			Handler:    _CompactorScheduler_LeaseJob_Handler,
		},
		{
			MethodName: "PlannedJobs",
			Handler:    _CompactorScheduler_PlannedJobs_Handler,
		},
		{
			MethodName: "UpdatePlanJob",
			Handler:    _CompactorScheduler_UpdatePlanJob_Handler,
		},
		{
			MethodName: "UpdateCompactionJob",
			Handler:    _CompactorScheduler_UpdateCompactionJob_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "compactorscheduler.proto",
}

func (m *JobKey) Marshal() (dAtA []byte, err error) {
	size := m.Size()
	dAtA = make([]byte, size)
	n, err := m.MarshalToSizedBuffer(dAtA[:size])
	if err != nil {
		return nil, err
	}
	return dAtA[:n], nil
}

func (m *JobKey) MarshalTo(dAtA []byte) (int, error) {
	size := m.Size()
	return m.MarshalToSizedBuffer(dAtA[:size])
}

func (m *JobKey) MarshalToSizedBuffer(dAtA []byte) (int, error) {
	i := len(dAtA)
	_ = i
	var l int
	_ = l
	if m.Epoch != 0 {
		i = encodeVarintCompactorscheduler(dAtA, i, uint64(m.Epoch))
		i--
		dAtA[i] = 0x10
	}
	if len(m.Id) > 0 {
		i -= len(m.Id)
		copy(dAtA[i:], m.Id)
		i = encodeVarintCompactorscheduler(dAtA, i, uint64(len(m.Id)))
		i--
		dAtA[i] = 0xa
	}
	return len(dAtA) - i, nil
}

func (m *JobSpec) Marshal() (dAtA []byte, err error) {
	size := m.Size()
	dAtA = make([]byte, size)
	n, err := m.MarshalToSizedBuffer(dAtA[:size])
	if err != nil {
		return nil, err
	}
	return dAtA[:n], nil
}

func (m *JobSpec) MarshalTo(dAtA []byte) (int, error) {
	size := m.Size()
	return m.MarshalToSizedBuffer(dAtA[:size])
}

func (m *JobSpec) MarshalToSizedBuffer(dAtA []byte) (int, error) {
	i := len(dAtA)
	_ = i
	var l int
	_ = l
	if m.JobType != 0 {
		i = encodeVarintCompactorscheduler(dAtA, i, uint64(m.JobType))
		i--
		dAtA[i] = 0x18
	}
	if m.Job != nil {
		{
			size, err := m.Job.MarshalToSizedBuffer(dAtA[:i])
			if err != nil {
				return 0, err
			}
			i -= size
			i = encodeVarintCompactorscheduler(dAtA, i, uint64(size))
		}
		i--
		dAtA[i] = 0x12
	}
	if len(m.Tenant) > 0 {
		i -= len(m.Tenant)
		copy(dAtA[i:], m.Tenant)
		i = encodeVarintCompactorscheduler(dAtA, i, uint64(len(m.Tenant)))
		i--
		dAtA[i] = 0xa
	}
	return len(dAtA) - i, nil
}

func (m *CompactionJob) Marshal() (dAtA []byte, err error) {
	size := m.Size()
	dAtA = make([]byte, size)
	n, err := m.MarshalToSizedBuffer(dAtA[:size])
	if err != nil {
		return nil, err
	}
	return dAtA[:n], nil
}

func (m *CompactionJob) MarshalTo(dAtA []byte) (int, error) {
	size := m.Size()
	return m.MarshalToSizedBuffer(dAtA[:size])
}

func (m *CompactionJob) MarshalToSizedBuffer(dAtA []byte) (int, error) {
	i := len(dAtA)
	_ = i
	var l int
	_ = l
	if m.TotalBlocksBytes != 0 {
		i = encodeVarintCompactorscheduler(dAtA, i, uint64(m.TotalBlocksBytes))
		i--
		dAtA[i] = 0x18
	}
	if m.Split {
		i--
		if m.Split {
			dAtA[i] = 1
		} else {
			dAtA[i] = 0
		}
		i--
		dAtA[i] = 0x10
	}
	if len(m.BlockIds) > 0 {
		for iNdEx := len(m.BlockIds) - 1; iNdEx >= 0; iNdEx-- {
			i -= len(m.BlockIds[iNdEx])
			copy(dAtA[i:], m.BlockIds[iNdEx])
			i = encodeVarintCompactorscheduler(dAtA, i, uint64(len(m.BlockIds[iNdEx])))
			i--
			dAtA[i] = 0xa
		}
	}
	return len(dAtA) - i, nil
}

func (m *LeaseJobRequest) Marshal() (dAtA []byte, err error) {
	size := m.Size()
	dAtA = make([]byte, size)
	n, err := m.MarshalToSizedBuffer(dAtA[:size])
	if err != nil {
		return nil, err
	}
	return dAtA[:n], nil
}

func (m *LeaseJobRequest) MarshalTo(dAtA []byte) (int, error) {
	size := m.Size()
	return m.MarshalToSizedBuffer(dAtA[:size])
}

func (m *LeaseJobRequest) MarshalToSizedBuffer(dAtA []byte) (int, error) {
	i := len(dAtA)
	_ = i
	var l int
	_ = l
	if len(m.WorkerId) > 0 {
		i -= len(m.WorkerId)
		copy(dAtA[i:], m.WorkerId)
		i = encodeVarintCompactorscheduler(dAtA, i, uint64(len(m.WorkerId)))
		i--
		dAtA[i] = 0xa
	}
	return len(dAtA) - i, nil
}

func (m *LeaseJobResponse) Marshal() (dAtA []byte, err error) {
	size := m.Size()
	dAtA = make([]byte, size)
	n, err := m.MarshalToSizedBuffer(dAtA[:size])
	if err != nil {
		return nil, err
	}
	return dAtA[:n], nil
}

func (m *LeaseJobResponse) MarshalTo(dAtA []byte) (int, error) {
	size := m.Size()
	return m.MarshalToSizedBuffer(dAtA[:size])
}

func (m *LeaseJobResponse) MarshalToSizedBuffer(dAtA []byte) (int, error) {
	i := len(dAtA)
	_ = i
	var l int
	_ = l
	if m.Spec != nil {
		{
			size, err := m.Spec.MarshalToSizedBuffer(dAtA[:i])
			if err != nil {
				return 0, err
			}
			i -= size
			i = encodeVarintCompactorscheduler(dAtA, i, uint64(size))
		}
		i--
		dAtA[i] = 0x12
	}
	if m.Key != nil {
		{
			size, err := m.Key.MarshalToSizedBuffer(dAtA[:i])
			if err != nil {
				return 0, err
			}
			i -= size
			i = encodeVarintCompactorscheduler(dAtA, i, uint64(size))
		}
		i--
		dAtA[i] = 0xa
	}
	return len(dAtA) - i, nil
}

func (m *PlannedCompactionJob) Marshal() (dAtA []byte, err error) {
	size := m.Size()
	dAtA = make([]byte, size)
	n, err := m.MarshalToSizedBuffer(dAtA[:size])
	if err != nil {
		return nil, err
	}
	return dAtA[:n], nil
}

func (m *PlannedCompactionJob) MarshalTo(dAtA []byte) (int, error) {
	size := m.Size()
	return m.MarshalToSizedBuffer(dAtA[:size])
}

func (m *PlannedCompactionJob) MarshalToSizedBuffer(dAtA []byte) (int, error) {
	i := len(dAtA)
	_ = i
	var l int
	_ = l
	if m.Job != nil {
		{
			size, err := m.Job.MarshalToSizedBuffer(dAtA[:i])
			if err != nil {
				return 0, err
			}
			i -= size
			i = encodeVarintCompactorscheduler(dAtA, i, uint64(size))
		}
		i--
		dAtA[i] = 0x12
	}
	if len(m.Id) > 0 {
		i -= len(m.Id)
		copy(dAtA[i:], m.Id)
		i = encodeVarintCompactorscheduler(dAtA, i, uint64(len(m.Id)))
		i--
		dAtA[i] = 0xa
	}
	return len(dAtA) - i, nil
}

func (m *PlannedJobsRequest) Marshal() (dAtA []byte, err error) {
	size := m.Size()
	dAtA = make([]byte, size)
	n, err := m.MarshalToSizedBuffer(dAtA[:size])
	if err != nil {
		return nil, err
	}
	return dAtA[:n], nil
}

func (m *PlannedJobsRequest) MarshalTo(dAtA []byte) (int, error) {
	size := m.Size()
	return m.MarshalToSizedBuffer(dAtA[:size])
}

func (m *PlannedJobsRequest) MarshalToSizedBuffer(dAtA []byte) (int, error) {
	i := len(dAtA)
	_ = i
	var l int
	_ = l
	if len(m.Jobs) > 0 {
		for iNdEx := len(m.Jobs) - 1; iNdEx >= 0; iNdEx-- {
			{
				size, err := m.Jobs[iNdEx].MarshalToSizedBuffer(dAtA[:i])
				if err != nil {
					return 0, err
				}
				i -= size
				i = encodeVarintCompactorscheduler(dAtA, i, uint64(size))
			}
			i--
			dAtA[i] = 0x1a
		}
	}
	if len(m.Tenant) > 0 {
		i -= len(m.Tenant)
		copy(dAtA[i:], m.Tenant)
		i = encodeVarintCompactorscheduler(dAtA, i, uint64(len(m.Tenant)))
		i--
		dAtA[i] = 0x12
	}
	if m.Key != nil {
		{
			size, err := m.Key.MarshalToSizedBuffer(dAtA[:i])
			if err != nil {
				return 0, err
			}
			i -= size
			i = encodeVarintCompactorscheduler(dAtA, i, uint64(size))
		}
		i--
		dAtA[i] = 0xa
	}
	return len(dAtA) - i, nil
}

func (m *PlannedJobsResponse) Marshal() (dAtA []byte, err error) {
	size := m.Size()
	dAtA = make([]byte, size)
	n, err := m.MarshalToSizedBuffer(dAtA[:size])
	if err != nil {
		return nil, err
	}
	return dAtA[:n], nil
}

func (m *PlannedJobsResponse) MarshalTo(dAtA []byte) (int, error) {
	size := m.Size()
	return m.MarshalToSizedBuffer(dAtA[:size])
}

func (m *PlannedJobsResponse) MarshalToSizedBuffer(dAtA []byte) (int, error) {
	i := len(dAtA)
	_ = i
	var l int
	_ = l
	return len(dAtA) - i, nil
}

func (m *UpdatePlanJobRequest) Marshal() (dAtA []byte, err error) {
	size := m.Size()
	dAtA = make([]byte, size)
	n, err := m.MarshalToSizedBuffer(dAtA[:size])
	if err != nil {
		return nil, err
	}
	return dAtA[:n], nil
}

func (m *UpdatePlanJobRequest) MarshalTo(dAtA []byte) (int, error) {
	size := m.Size()
	return m.MarshalToSizedBuffer(dAtA[:size])
}

func (m *UpdatePlanJobRequest) MarshalToSizedBuffer(dAtA []byte) (int, error) {
	i := len(dAtA)
	_ = i
	var l int
	_ = l
	if m.Update != 0 {
		i = encodeVarintCompactorscheduler(dAtA, i, uint64(m.Update))
		i--
		dAtA[i] = 0x18
	}
	if len(m.Tenant) > 0 {
		i -= len(m.Tenant)
		copy(dAtA[i:], m.Tenant)
		i = encodeVarintCompactorscheduler(dAtA, i, uint64(len(m.Tenant)))
		i--
		dAtA[i] = 0x12
	}
	if m.Key != nil {
		{
			size, err := m.Key.MarshalToSizedBuffer(dAtA[:i])
			if err != nil {
				return 0, err
			}
			i -= size
			i = encodeVarintCompactorscheduler(dAtA, i, uint64(size))
		}
		i--
		dAtA[i] = 0xa
	}
	return len(dAtA) - i, nil
}

func (m *UpdateCompactionJobRequest) Marshal() (dAtA []byte, err error) {
	size := m.Size()
	dAtA = make([]byte, size)
	n, err := m.MarshalToSizedBuffer(dAtA[:size])
	if err != nil {
		return nil, err
	}
	return dAtA[:n], nil
}

func (m *UpdateCompactionJobRequest) MarshalTo(dAtA []byte) (int, error) {
	size := m.Size()
	return m.MarshalToSizedBuffer(dAtA[:size])
}

func (m *UpdateCompactionJobRequest) MarshalToSizedBuffer(dAtA []byte) (int, error) {
	i := len(dAtA)
	_ = i
	var l int
	_ = l
	if m.Update != 0 {
		i = encodeVarintCompactorscheduler(dAtA, i, uint64(m.Update))
		i--
		dAtA[i] = 0x18
	}
	if len(m.Tenant) > 0 {
		i -= len(m.Tenant)
		copy(dAtA[i:], m.Tenant)
		i = encodeVarintCompactorscheduler(dAtA, i, uint64(len(m.Tenant)))
		i--
		dAtA[i] = 0x12
	}
	if m.Key != nil {
		{
			size, err := m.Key.MarshalToSizedBuffer(dAtA[:i])
			if err != nil {
				return 0, err
			}
			i -= size
			i = encodeVarintCompactorscheduler(dAtA, i, uint64(size))
		}
		i--
		dAtA[i] = 0xa
	}
	return len(dAtA) - i, nil
}

func (m *UpdateJobResponse) Marshal() (dAtA []byte, err error) {
	size := m.Size()
	dAtA = make([]byte, size)
	n, err := m.MarshalToSizedBuffer(dAtA[:size])
	if err != nil {
		return nil, err
	}
	return dAtA[:n], nil
}

func (m *UpdateJobResponse) MarshalTo(dAtA []byte) (int, error) {
	size := m.Size()
	return m.MarshalToSizedBuffer(dAtA[:size])
}

func (m *UpdateJobResponse) MarshalToSizedBuffer(dAtA []byte) (int, error) {
	i := len(dAtA)
	_ = i
	var l int
	_ = l
	return len(dAtA) - i, nil
}

func (m *StoredJobInfo) Marshal() (dAtA []byte, err error) {
	size := m.Size()
	dAtA = make([]byte, size)
	n, err := m.MarshalToSizedBuffer(dAtA[:size])
	if err != nil {
		return nil, err
	}
	return dAtA[:n], nil
}

func (m *StoredJobInfo) MarshalTo(dAtA []byte) (int, error) {
	size := m.Size()
	return m.MarshalToSizedBuffer(dAtA[:size])
}

func (m *StoredJobInfo) MarshalToSizedBuffer(dAtA []byte) (int, error) {
	i := len(dAtA)
	_ = i
	var l int
	_ = l
	if m.Epoch != 0 {
		i = encodeVarintCompactorscheduler(dAtA, i, uint64(m.Epoch))
		i--
		dAtA[i] = 0x28
	}
	if m.NumLeases != 0 {
		i = encodeVarintCompactorscheduler(dAtA, i, uint64(m.NumLeases))
		i--
		dAtA[i] = 0x20
	}
	if m.StatusTime != 0 {
		i = encodeVarintCompactorscheduler(dAtA, i, uint64(m.StatusTime))
		i--
		dAtA[i] = 0x18
	}
	if m.Status != 0 {
		i = encodeVarintCompactorscheduler(dAtA, i, uint64(m.Status))
		i--
		dAtA[i] = 0x10
	}
	if m.CreationTime != 0 {
		i = encodeVarintCompactorscheduler(dAtA, i, uint64(m.CreationTime))
		i--
		dAtA[i] = 0x8
	}
	return len(dAtA) - i, nil
}

func (m *StoredCompactionJob) Marshal() (dAtA []byte, err error) {
	size := m.Size()
	dAtA = make([]byte, size)
	n, err := m.MarshalToSizedBuffer(dAtA[:size])
	if err != nil {
		return nil, err
	}
	return dAtA[:n], nil
}

func (m *StoredCompactionJob) MarshalTo(dAtA []byte) (int, error) {
	size := m.Size()
	return m.MarshalToSizedBuffer(dAtA[:size])
}

func (m *StoredCompactionJob) MarshalToSizedBuffer(dAtA []byte) (int, error) {
	i := len(dAtA)
	_ = i
	var l int
	_ = l
	if m.Order != 0 {
		i = encodeVarintCompactorscheduler(dAtA, i, uint64(m.Order))
		i--
		dAtA[i] = 0x18
	}
	if m.Job != nil {
		{
			size, err := m.Job.MarshalToSizedBuffer(dAtA[:i])
			if err != nil {
				return 0, err
			}
			i -= size
			i = encodeVarintCompactorscheduler(dAtA, i, uint64(size))
		}
		i--
		dAtA[i] = 0x12
	}
	if m.Info != nil {
		{
			size, err := m.Info.MarshalToSizedBuffer(dAtA[:i])
			if err != nil {
				return 0, err
			}
			i -= size
			i = encodeVarintCompactorscheduler(dAtA, i, uint64(size))
		}
		i--
		dAtA[i] = 0xa
	}
	return len(dAtA) - i, nil
}

func (m *PersistenceMetadata) Marshal() (dAtA []byte, err error) {
	size := m.Size()
	dAtA = make([]byte, size)
	n, err := m.MarshalToSizedBuffer(dAtA[:size])
	if err != nil {
		return nil, err
	}
	return dAtA[:n], nil
}

func (m *PersistenceMetadata) MarshalTo(dAtA []byte) (int, error) {
	size := m.Size()
	return m.MarshalToSizedBuffer(dAtA[:size])
}

func (m *PersistenceMetadata) MarshalToSizedBuffer(dAtA []byte) (int, error) {
	i := len(dAtA)
	_ = i
	var l int
	_ = l
	if m.CreationTime != 0 {
		i = encodeVarintCompactorscheduler(dAtA, i, uint64(m.CreationTime))
		i--
		dAtA[i] = 0x10
	}
	if m.ShardCount != 0 {
		i = encodeVarintCompactorscheduler(dAtA, i, uint64(m.ShardCount))
		i--
		dAtA[i] = 0x8
	}
	return len(dAtA) - i, nil
}

func encodeVarintCompactorscheduler(dAtA []byte, offset int, v uint64) int {
	offset -= sovCompactorscheduler(v)
	base := offset
	for v >= 1<<7 {
		dAtA[offset] = uint8(v&0x7f | 0x80)
		v >>= 7
		offset++
	}
	dAtA[offset] = uint8(v)
	return base
}
func (m *JobKey) Size() (n int) {
	if m == nil {
		return 0
	}
	var l int
	_ = l
	l = len(m.Id)
	if l > 0 {
		n += 1 + l + sovCompactorscheduler(uint64(l))
	}
	if m.Epoch != 0 {
		n += 1 + sovCompactorscheduler(uint64(m.Epoch))
	}
	return n
}

func (m *JobSpec) Size() (n int) {
	if m == nil {
		return 0
	}
	var l int
	_ = l
	l = len(m.Tenant)
	if l > 0 {
		n += 1 + l + sovCompactorscheduler(uint64(l))
	}
	if m.Job != nil {
		l = m.Job.Size()
		n += 1 + l + sovCompactorscheduler(uint64(l))
	}
	if m.JobType != 0 {
		n += 1 + sovCompactorscheduler(uint64(m.JobType))
	}
	return n
}

func (m *CompactionJob) Size() (n int) {
	if m == nil {
		return 0
	}
	var l int
	_ = l
	if len(m.BlockIds) > 0 {
		for _, b := range m.BlockIds {
			l = len(b)
			n += 1 + l + sovCompactorscheduler(uint64(l))
		}
	}
	if m.Split {
		n += 2
	}
	if m.TotalBlocksBytes != 0 {
		n += 1 + sovCompactorscheduler(uint64(m.TotalBlocksBytes))
	}
	return n
}

func (m *LeaseJobRequest) Size() (n int) {
	if m == nil {
		return 0
	}
	var l int
	_ = l
	l = len(m.WorkerId)
	if l > 0 {
		n += 1 + l + sovCompactorscheduler(uint64(l))
	}
	return n
}

func (m *LeaseJobResponse) Size() (n int) {
	if m == nil {
		return 0
	}
	var l int
	_ = l
	if m.Key != nil {
		l = m.Key.Size()
		n += 1 + l + sovCompactorscheduler(uint64(l))
	}
	if m.Spec != nil {
		l = m.Spec.Size()
		n += 1 + l + sovCompactorscheduler(uint64(l))
	}
	return n
}

func (m *PlannedCompactionJob) Size() (n int) {
	if m == nil {
		return 0
	}
	var l int
	_ = l
	l = len(m.Id)
	if l > 0 {
		n += 1 + l + sovCompactorscheduler(uint64(l))
	}
	if m.Job != nil {
		l = m.Job.Size()
		n += 1 + l + sovCompactorscheduler(uint64(l))
	}
	return n
}

func (m *PlannedJobsRequest) Size() (n int) {
	if m == nil {
		return 0
	}
	var l int
	_ = l
	if m.Key != nil {
		l = m.Key.Size()
		n += 1 + l + sovCompactorscheduler(uint64(l))
	}
	l = len(m.Tenant)
	if l > 0 {
		n += 1 + l + sovCompactorscheduler(uint64(l))
	}
	if len(m.Jobs) > 0 {
		for _, e := range m.Jobs {
			l = e.Size()
			n += 1 + l + sovCompactorscheduler(uint64(l))
		}
	}
	return n
}

func (m *PlannedJobsResponse) Size() (n int) {
	if m == nil {
		return 0
	}
	var l int
	_ = l
	return n
}

func (m *UpdatePlanJobRequest) Size() (n int) {
	if m == nil {
		return 0
	}
	var l int
	_ = l
	if m.Key != nil {
		l = m.Key.Size()
		n += 1 + l + sovCompactorscheduler(uint64(l))
	}
	l = len(m.Tenant)
	if l > 0 {
		n += 1 + l + sovCompactorscheduler(uint64(l))
	}
	if m.Update != 0 {
		n += 1 + sovCompactorscheduler(uint64(m.Update))
	}
	return n
}

func (m *UpdateCompactionJobRequest) Size() (n int) {
	if m == nil {
		return 0
	}
	var l int
	_ = l
	if m.Key != nil {
		l = m.Key.Size()
		n += 1 + l + sovCompactorscheduler(uint64(l))
	}
	l = len(m.Tenant)
	if l > 0 {
		n += 1 + l + sovCompactorscheduler(uint64(l))
	}
	if m.Update != 0 {
		n += 1 + sovCompactorscheduler(uint64(m.Update))
	}
	return n
}

func (m *UpdateJobResponse) Size() (n int) {
	if m == nil {
		return 0
	}
	var l int
	_ = l
	return n
}

func (m *StoredJobInfo) Size() (n int) {
	if m == nil {
		return 0
	}
	var l int
	_ = l
	if m.CreationTime != 0 {
		n += 1 + sovCompactorscheduler(uint64(m.CreationTime))
	}
	if m.Status != 0 {
		n += 1 + sovCompactorscheduler(uint64(m.Status))
	}
	if m.StatusTime != 0 {
		n += 1 + sovCompactorscheduler(uint64(m.StatusTime))
	}
	if m.NumLeases != 0 {
		n += 1 + sovCompactorscheduler(uint64(m.NumLeases))
	}
	if m.Epoch != 0 {
		n += 1 + sovCompactorscheduler(uint64(m.Epoch))
	}
	return n
}

func (m *StoredCompactionJob) Size() (n int) {
	if m == nil {
		return 0
	}
	var l int
	_ = l
	if m.Info != nil {
		l = m.Info.Size()
		n += 1 + l + sovCompactorscheduler(uint64(l))
	}
	if m.Job != nil {
		l = m.Job.Size()
		n += 1 + l + sovCompactorscheduler(uint64(l))
	}
	if m.Order != 0 {
		n += 1 + sovCompactorscheduler(uint64(m.Order))
	}
	return n
}

func (m *PersistenceMetadata) Size() (n int) {
	if m == nil {
		return 0
	}
	var l int
	_ = l
	if m.ShardCount != 0 {
		n += 1 + sovCompactorscheduler(uint64(m.ShardCount))
	}
	if m.CreationTime != 0 {
		n += 1 + sovCompactorscheduler(uint64(m.CreationTime))
	}
	return n
}

func sovCompactorscheduler(x uint64) (n int) {
	return (math_bits.Len64(x|1) + 6) / 7
}
func sozCompactorscheduler(x uint64) (n int) {
	return sovCompactorscheduler(uint64((x << 1) ^ uint64((int64(x) >> 63))))
}
func (this *JobKey) String() string {
	if this == nil {
		return "nil"
	}
	s := strings.Join([]string{`&JobKey{`,
		`Id:` + fmt.Sprintf("%v", this.Id) + `,`,
		`Epoch:` + fmt.Sprintf("%v", this.Epoch) + `,`,
		`}`,
	}, "")
	return s
}
func (this *JobSpec) String() string {
	if this == nil {
		return "nil"
	}
	s := strings.Join([]string{`&JobSpec{`,
		`Tenant:` + fmt.Sprintf("%v", this.Tenant) + `,`,
		`Job:` + strings.Replace(this.Job.String(), "CompactionJob", "CompactionJob", 1) + `,`,
		`JobType:` + fmt.Sprintf("%v", this.JobType) + `,`,
		`}`,
	}, "")
	return s
}
func (this *CompactionJob) String() string {
	if this == nil {
		return "nil"
	}
	s := strings.Join([]string{`&CompactionJob{`,
		`BlockIds:` + fmt.Sprintf("%v", this.BlockIds) + `,`,
		`Split:` + fmt.Sprintf("%v", this.Split) + `,`,
		`TotalBlocksBytes:` + fmt.Sprintf("%v", this.TotalBlocksBytes) + `,`,
		`}`,
	}, "")
	return s
}
func (this *LeaseJobRequest) String() string {
	if this == nil {
		return "nil"
	}
	s := strings.Join([]string{`&LeaseJobRequest{`,
		`WorkerId:` + fmt.Sprintf("%v", this.WorkerId) + `,`,
		`}`,
	}, "")
	return s
}
func (this *LeaseJobResponse) String() string {
	if this == nil {
		return "nil"
	}
	s := strings.Join([]string{`&LeaseJobResponse{`,
		`Key:` + strings.Replace(this.Key.String(), "JobKey", "JobKey", 1) + `,`,
		`Spec:` + strings.Replace(this.Spec.String(), "JobSpec", "JobSpec", 1) + `,`,
		`}`,
	}, "")
	return s
}
func (this *PlannedCompactionJob) String() string {
	if this == nil {
		return "nil"
	}
	s := strings.Join([]string{`&PlannedCompactionJob{`,
		`Id:` + fmt.Sprintf("%v", this.Id) + `,`,
		`Job:` + strings.Replace(this.Job.String(), "CompactionJob", "CompactionJob", 1) + `,`,
		`}`,
	}, "")
	return s
}
func (this *PlannedJobsRequest) String() string {
	if this == nil {
		return "nil"
	}
	repeatedStringForJobs := "[]*PlannedCompactionJob{"
	for _, f := range this.Jobs {
		repeatedStringForJobs += strings.Replace(f.String(), "PlannedCompactionJob", "PlannedCompactionJob", 1) + ","
	}
	repeatedStringForJobs += "}"
	s := strings.Join([]string{`&PlannedJobsRequest{`,
		`Key:` + strings.Replace(this.Key.String(), "JobKey", "JobKey", 1) + `,`,
		`Tenant:` + fmt.Sprintf("%v", this.Tenant) + `,`,
		`Jobs:` + repeatedStringForJobs + `,`,
		`}`,
	}, "")
	return s
}
func (this *PlannedJobsResponse) String() string {
	if this == nil {
		return "nil"
	}
	s := strings.Join([]string{`&PlannedJobsResponse{`,
		`}`,
	}, "")
	return s
}
func (this *UpdatePlanJobRequest) String() string {
	if this == nil {
		return "nil"
	}
	s := strings.Join([]string{`&UpdatePlanJobRequest{`,
		`Key:` + strings.Replace(this.Key.String(), "JobKey", "JobKey", 1) + `,`,
		`Tenant:` + fmt.Sprintf("%v", this.Tenant) + `,`,
		`Update:` + fmt.Sprintf("%v", this.Update) + `,`,
		`}`,
	}, "")
	return s
}
func (this *UpdateCompactionJobRequest) String() string {
	if this == nil {
		return "nil"
	}
	s := strings.Join([]string{`&UpdateCompactionJobRequest{`,
		`Key:` + strings.Replace(this.Key.String(), "JobKey", "JobKey", 1) + `,`,
		`Tenant:` + fmt.Sprintf("%v", this.Tenant) + `,`,
		`Update:` + fmt.Sprintf("%v", this.Update) + `,`,
		`}`,
	}, "")
	return s
}
func (this *UpdateJobResponse) String() string {
	if this == nil {
		return "nil"
	}
	s := strings.Join([]string{`&UpdateJobResponse{`,
		`}`,
	}, "")
	return s
}
func (this *StoredJobInfo) String() string {
	if this == nil {
		return "nil"
	}
	s := strings.Join([]string{`&StoredJobInfo{`,
		`CreationTime:` + fmt.Sprintf("%v", this.CreationTime) + `,`,
		`Status:` + fmt.Sprintf("%v", this.Status) + `,`,
		`StatusTime:` + fmt.Sprintf("%v", this.StatusTime) + `,`,
		`NumLeases:` + fmt.Sprintf("%v", this.NumLeases) + `,`,
		`Epoch:` + fmt.Sprintf("%v", this.Epoch) + `,`,
		`}`,
	}, "")
	return s
}
func (this *StoredCompactionJob) String() string {
	if this == nil {
		return "nil"
	}
	s := strings.Join([]string{`&StoredCompactionJob{`,
		`Info:` + strings.Replace(this.Info.String(), "StoredJobInfo", "StoredJobInfo", 1) + `,`,
		`Job:` + strings.Replace(this.Job.String(), "CompactionJob", "CompactionJob", 1) + `,`,
		`Order:` + fmt.Sprintf("%v", this.Order) + `,`,
		`}`,
	}, "")
	return s
}
func (this *PersistenceMetadata) String() string {
	if this == nil {
		return "nil"
	}
	s := strings.Join([]string{`&PersistenceMetadata{`,
		`ShardCount:` + fmt.Sprintf("%v", this.ShardCount) + `,`,
		`CreationTime:` + fmt.Sprintf("%v", this.CreationTime) + `,`,
		`}`,
	}, "")
	return s
}
func valueToStringCompactorscheduler(v interface{}) string {
	rv := reflect.ValueOf(v)
	if rv.IsNil() {
		return "nil"
	}
	pv := reflect.Indirect(rv).Interface()
	return fmt.Sprintf("*%v", pv)
}
func (m *JobKey) Unmarshal(dAtA []byte) error {
	l := len(dAtA)
	iNdEx := 0
	for iNdEx < l {
		preIndex := iNdEx
		var wire uint64
		for shift := uint(0); ; shift += 7 {
			if shift >= 64 {
				return ErrIntOverflowCompactorscheduler
			}
			if iNdEx >= l {
				return io.ErrUnexpectedEOF
			}
			b := dAtA[iNdEx]
			iNdEx++
			wire |= uint64(b&0x7F) << shift
			if b < 0x80 {
				break
			}
		}
		fieldNum := int32(wire >> 3)
		wireType := int(wire & 0x7)
		if wireType == 4 {
			return fmt.Errorf("proto: JobKey: wiretype end group for non-group")
		}
		if fieldNum <= 0 {
			return fmt.Errorf("proto: JobKey: illegal tag %d (wire type %d)", fieldNum, wire)
		}
		switch fieldNum {
		case 1:
			if wireType != 2 {
				return fmt.Errorf("proto: wrong wireType = %d for field Id", wireType)
			}
			var stringLen uint64
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				stringLen |= uint64(b&0x7F) << shift
				if b < 0x80 {
					break
				}
			}
			intStringLen := int(stringLen)
			if intStringLen < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			postIndex := iNdEx + intStringLen
			if postIndex < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			if postIndex > l {
				return io.ErrUnexpectedEOF
			}
			m.Id = string(dAtA[iNdEx:postIndex])
			iNdEx = postIndex
		case 2:
			if wireType != 0 {
				return fmt.Errorf("proto: wrong wireType = %d for field Epoch", wireType)
			}
			m.Epoch = 0
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				m.Epoch |= int64(b&0x7F) << shift
				if b < 0x80 {
					break
				}
			}
		default:
			iNdEx = preIndex
			skippy, err := skipCompactorscheduler(dAtA[iNdEx:])
			if err != nil {
				return err
			}
			if (skippy < 0) || (iNdEx+skippy) < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			if (iNdEx + skippy) > l {
				return io.ErrUnexpectedEOF
			}
			iNdEx += skippy
		}
	}

	if iNdEx > l {
		return io.ErrUnexpectedEOF
	}
	return nil
}
func (m *JobSpec) Unmarshal(dAtA []byte) error {
	l := len(dAtA)
	iNdEx := 0
	for iNdEx < l {
		preIndex := iNdEx
		var wire uint64
		for shift := uint(0); ; shift += 7 {
			if shift >= 64 {
				return ErrIntOverflowCompactorscheduler
			}
			if iNdEx >= l {
				return io.ErrUnexpectedEOF
			}
			b := dAtA[iNdEx]
			iNdEx++
			wire |= uint64(b&0x7F) << shift
			if b < 0x80 {
				break
			}
		}
		fieldNum := int32(wire >> 3)
		wireType := int(wire & 0x7)
		if wireType == 4 {
			return fmt.Errorf("proto: JobSpec: wiretype end group for non-group")
		}
		if fieldNum <= 0 {
			return fmt.Errorf("proto: JobSpec: illegal tag %d (wire type %d)", fieldNum, wire)
		}
		switch fieldNum {
		case 1:
			if wireType != 2 {
				return fmt.Errorf("proto: wrong wireType = %d for field Tenant", wireType)
			}
			var stringLen uint64
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				stringLen |= uint64(b&0x7F) << shift
				if b < 0x80 {
					break
				}
			}
			intStringLen := int(stringLen)
			if intStringLen < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			postIndex := iNdEx + intStringLen
			if postIndex < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			if postIndex > l {
				return io.ErrUnexpectedEOF
			}
			m.Tenant = string(dAtA[iNdEx:postIndex])
			iNdEx = postIndex
		case 2:
			if wireType != 2 {
				return fmt.Errorf("proto: wrong wireType = %d for field Job", wireType)
			}
			var msglen int
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				msglen |= int(b&0x7F) << shift
				if b < 0x80 {
					break
				}
			}
			if msglen < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			postIndex := iNdEx + msglen
			if postIndex < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			if postIndex > l {
				return io.ErrUnexpectedEOF
			}
			if m.Job == nil {
				m.Job = &CompactionJob{}
			}
			if err := m.Job.Unmarshal(dAtA[iNdEx:postIndex]); err != nil {
				return err
			}
			iNdEx = postIndex
		case 3:
			if wireType != 0 {
				return fmt.Errorf("proto: wrong wireType = %d for field JobType", wireType)
			}
			m.JobType = 0
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				m.JobType |= JobType(b&0x7F) << shift
				if b < 0x80 {
					break
				}
			}
		default:
			iNdEx = preIndex
			skippy, err := skipCompactorscheduler(dAtA[iNdEx:])
			if err != nil {
				return err
			}
			if (skippy < 0) || (iNdEx+skippy) < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			if (iNdEx + skippy) > l {
				return io.ErrUnexpectedEOF
			}
			iNdEx += skippy
		}
	}

	if iNdEx > l {
		return io.ErrUnexpectedEOF
	}
	return nil
}
func (m *CompactionJob) Unmarshal(dAtA []byte) error {
	l := len(dAtA)
	iNdEx := 0
	for iNdEx < l {
		preIndex := iNdEx
		var wire uint64
		for shift := uint(0); ; shift += 7 {
			if shift >= 64 {
				return ErrIntOverflowCompactorscheduler
			}
			if iNdEx >= l {
				return io.ErrUnexpectedEOF
			}
			b := dAtA[iNdEx]
			iNdEx++
			wire |= uint64(b&0x7F) << shift
			if b < 0x80 {
				break
			}
		}
		fieldNum := int32(wire >> 3)
		wireType := int(wire & 0x7)
		if wireType == 4 {
			return fmt.Errorf("proto: CompactionJob: wiretype end group for non-group")
		}
		if fieldNum <= 0 {
			return fmt.Errorf("proto: CompactionJob: illegal tag %d (wire type %d)", fieldNum, wire)
		}
		switch fieldNum {
		case 1:
			if wireType != 2 {
				return fmt.Errorf("proto: wrong wireType = %d for field BlockIds", wireType)
			}
			var byteLen int
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				byteLen |= int(b&0x7F) << shift
				if b < 0x80 {
					break
				}
			}
			if byteLen < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			postIndex := iNdEx + byteLen
			if postIndex < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			if postIndex > l {
				return io.ErrUnexpectedEOF
			}
			m.BlockIds = append(m.BlockIds, make([]byte, postIndex-iNdEx))
			copy(m.BlockIds[len(m.BlockIds)-1], dAtA[iNdEx:postIndex])
			iNdEx = postIndex
		case 2:
			if wireType != 0 {
				return fmt.Errorf("proto: wrong wireType = %d for field Split", wireType)
			}
			var v int
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				v |= int(b&0x7F) << shift
				if b < 0x80 {
					break
				}
			}
			m.Split = bool(v != 0)
		case 3:
			if wireType != 0 {
				return fmt.Errorf("proto: wrong wireType = %d for field TotalBlocksBytes", wireType)
			}
			m.TotalBlocksBytes = 0
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				m.TotalBlocksBytes |= uint64(b&0x7F) << shift
				if b < 0x80 {
					break
				}
			}
		default:
			iNdEx = preIndex
			skippy, err := skipCompactorscheduler(dAtA[iNdEx:])
			if err != nil {
				return err
			}
			if (skippy < 0) || (iNdEx+skippy) < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			if (iNdEx + skippy) > l {
				return io.ErrUnexpectedEOF
			}
			iNdEx += skippy
		}
	}

	if iNdEx > l {
		return io.ErrUnexpectedEOF
	}
	return nil
}
func (m *LeaseJobRequest) Unmarshal(dAtA []byte) error {
	l := len(dAtA)
	iNdEx := 0
	for iNdEx < l {
		preIndex := iNdEx
		var wire uint64
		for shift := uint(0); ; shift += 7 {
			if shift >= 64 {
				return ErrIntOverflowCompactorscheduler
			}
			if iNdEx >= l {
				return io.ErrUnexpectedEOF
			}
			b := dAtA[iNdEx]
			iNdEx++
			wire |= uint64(b&0x7F) << shift
			if b < 0x80 {
				break
			}
		}
		fieldNum := int32(wire >> 3)
		wireType := int(wire & 0x7)
		if wireType == 4 {
			return fmt.Errorf("proto: LeaseJobRequest: wiretype end group for non-group")
		}
		if fieldNum <= 0 {
			return fmt.Errorf("proto: LeaseJobRequest: illegal tag %d (wire type %d)", fieldNum, wire)
		}
		switch fieldNum {
		case 1:
			if wireType != 2 {
				return fmt.Errorf("proto: wrong wireType = %d for field WorkerId", wireType)
			}
			var stringLen uint64
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				stringLen |= uint64(b&0x7F) << shift
				if b < 0x80 {
					break
				}
			}
			intStringLen := int(stringLen)
			if intStringLen < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			postIndex := iNdEx + intStringLen
			if postIndex < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			if postIndex > l {
				return io.ErrUnexpectedEOF
			}
			m.WorkerId = string(dAtA[iNdEx:postIndex])
			iNdEx = postIndex
		default:
			iNdEx = preIndex
			skippy, err := skipCompactorscheduler(dAtA[iNdEx:])
			if err != nil {
				return err
			}
			if (skippy < 0) || (iNdEx+skippy) < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			if (iNdEx + skippy) > l {
				return io.ErrUnexpectedEOF
			}
			iNdEx += skippy
		}
	}

	if iNdEx > l {
		return io.ErrUnexpectedEOF
	}
	return nil
}
func (m *LeaseJobResponse) Unmarshal(dAtA []byte) error {
	l := len(dAtA)
	iNdEx := 0
	for iNdEx < l {
		preIndex := iNdEx
		var wire uint64
		for shift := uint(0); ; shift += 7 {
			if shift >= 64 {
				return ErrIntOverflowCompactorscheduler
			}
			if iNdEx >= l {
				return io.ErrUnexpectedEOF
			}
			b := dAtA[iNdEx]
			iNdEx++
			wire |= uint64(b&0x7F) << shift
			if b < 0x80 {
				break
			}
		}
		fieldNum := int32(wire >> 3)
		wireType := int(wire & 0x7)
		if wireType == 4 {
			return fmt.Errorf("proto: LeaseJobResponse: wiretype end group for non-group")
		}
		if fieldNum <= 0 {
			return fmt.Errorf("proto: LeaseJobResponse: illegal tag %d (wire type %d)", fieldNum, wire)
		}
		switch fieldNum {
		case 1:
			if wireType != 2 {
				return fmt.Errorf("proto: wrong wireType = %d for field Key", wireType)
			}
			var msglen int
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				msglen |= int(b&0x7F) << shift
				if b < 0x80 {
					break
				}
			}
			if msglen < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			postIndex := iNdEx + msglen
			if postIndex < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			if postIndex > l {
				return io.ErrUnexpectedEOF
			}
			if m.Key == nil {
				m.Key = &JobKey{}
			}
			if err := m.Key.Unmarshal(dAtA[iNdEx:postIndex]); err != nil {
				return err
			}
			iNdEx = postIndex
		case 2:
			if wireType != 2 {
				return fmt.Errorf("proto: wrong wireType = %d for field Spec", wireType)
			}
			var msglen int
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				msglen |= int(b&0x7F) << shift
				if b < 0x80 {
					break
				}
			}
			if msglen < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			postIndex := iNdEx + msglen
			if postIndex < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			if postIndex > l {
				return io.ErrUnexpectedEOF
			}
			if m.Spec == nil {
				m.Spec = &JobSpec{}
			}
			if err := m.Spec.Unmarshal(dAtA[iNdEx:postIndex]); err != nil {
				return err
			}
			iNdEx = postIndex
		default:
			iNdEx = preIndex
			skippy, err := skipCompactorscheduler(dAtA[iNdEx:])
			if err != nil {
				return err
			}
			if (skippy < 0) || (iNdEx+skippy) < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			if (iNdEx + skippy) > l {
				return io.ErrUnexpectedEOF
			}
			iNdEx += skippy
		}
	}

	if iNdEx > l {
		return io.ErrUnexpectedEOF
	}
	return nil
}
func (m *PlannedCompactionJob) Unmarshal(dAtA []byte) error {
	l := len(dAtA)
	iNdEx := 0
	for iNdEx < l {
		preIndex := iNdEx
		var wire uint64
		for shift := uint(0); ; shift += 7 {
			if shift >= 64 {
				return ErrIntOverflowCompactorscheduler
			}
			if iNdEx >= l {
				return io.ErrUnexpectedEOF
			}
			b := dAtA[iNdEx]
			iNdEx++
			wire |= uint64(b&0x7F) << shift
			if b < 0x80 {
				break
			}
		}
		fieldNum := int32(wire >> 3)
		wireType := int(wire & 0x7)
		if wireType == 4 {
			return fmt.Errorf("proto: PlannedCompactionJob: wiretype end group for non-group")
		}
		if fieldNum <= 0 {
			return fmt.Errorf("proto: PlannedCompactionJob: illegal tag %d (wire type %d)", fieldNum, wire)
		}
		switch fieldNum {
		case 1:
			if wireType != 2 {
				return fmt.Errorf("proto: wrong wireType = %d for field Id", wireType)
			}
			var stringLen uint64
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				stringLen |= uint64(b&0x7F) << shift
				if b < 0x80 {
					break
				}
			}
			intStringLen := int(stringLen)
			if intStringLen < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			postIndex := iNdEx + intStringLen
			if postIndex < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			if postIndex > l {
				return io.ErrUnexpectedEOF
			}
			m.Id = string(dAtA[iNdEx:postIndex])
			iNdEx = postIndex
		case 2:
			if wireType != 2 {
				return fmt.Errorf("proto: wrong wireType = %d for field Job", wireType)
			}
			var msglen int
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				msglen |= int(b&0x7F) << shift
				if b < 0x80 {
					break
				}
			}
			if msglen < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			postIndex := iNdEx + msglen
			if postIndex < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			if postIndex > l {
				return io.ErrUnexpectedEOF
			}
			if m.Job == nil {
				m.Job = &CompactionJob{}
			}
			if err := m.Job.Unmarshal(dAtA[iNdEx:postIndex]); err != nil {
				return err
			}
			iNdEx = postIndex
		default:
			iNdEx = preIndex
			skippy, err := skipCompactorscheduler(dAtA[iNdEx:])
			if err != nil {
				return err
			}
			if (skippy < 0) || (iNdEx+skippy) < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			if (iNdEx + skippy) > l {
				return io.ErrUnexpectedEOF
			}
			iNdEx += skippy
		}
	}

	if iNdEx > l {
		return io.ErrUnexpectedEOF
	}
	return nil
}
func (m *PlannedJobsRequest) Unmarshal(dAtA []byte) error {
	l := len(dAtA)
	iNdEx := 0
	for iNdEx < l {
		preIndex := iNdEx
		var wire uint64
		for shift := uint(0); ; shift += 7 {
			if shift >= 64 {
				return ErrIntOverflowCompactorscheduler
			}
			if iNdEx >= l {
				return io.ErrUnexpectedEOF
			}
			b := dAtA[iNdEx]
			iNdEx++
			wire |= uint64(b&0x7F) << shift
			if b < 0x80 {
				break
			}
		}
		fieldNum := int32(wire >> 3)
		wireType := int(wire & 0x7)
		if wireType == 4 {
			return fmt.Errorf("proto: PlannedJobsRequest: wiretype end group for non-group")
		}
		if fieldNum <= 0 {
			return fmt.Errorf("proto: PlannedJobsRequest: illegal tag %d (wire type %d)", fieldNum, wire)
		}
		switch fieldNum {
		case 1:
			if wireType != 2 {
				return fmt.Errorf("proto: wrong wireType = %d for field Key", wireType)
			}
			var msglen int
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				msglen |= int(b&0x7F) << shift
				if b < 0x80 {
					break
				}
			}
			if msglen < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			postIndex := iNdEx + msglen
			if postIndex < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			if postIndex > l {
				return io.ErrUnexpectedEOF
			}
			if m.Key == nil {
				m.Key = &JobKey{}
			}
			if err := m.Key.Unmarshal(dAtA[iNdEx:postIndex]); err != nil {
				return err
			}
			iNdEx = postIndex
		case 2:
			if wireType != 2 {
				return fmt.Errorf("proto: wrong wireType = %d for field Tenant", wireType)
			}
			var stringLen uint64
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				stringLen |= uint64(b&0x7F) << shift
				if b < 0x80 {
					break
				}
			}
			intStringLen := int(stringLen)
			if intStringLen < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			postIndex := iNdEx + intStringLen
			if postIndex < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			if postIndex > l {
				return io.ErrUnexpectedEOF
			}
			m.Tenant = string(dAtA[iNdEx:postIndex])
			iNdEx = postIndex
		case 3:
			if wireType != 2 {
				return fmt.Errorf("proto: wrong wireType = %d for field Jobs", wireType)
			}
			var msglen int
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				msglen |= int(b&0x7F) << shift
				if b < 0x80 {
					break
				}
			}
			if msglen < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			postIndex := iNdEx + msglen
			if postIndex < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			if postIndex > l {
				return io.ErrUnexpectedEOF
			}
			m.Jobs = append(m.Jobs, &PlannedCompactionJob{})
			if err := m.Jobs[len(m.Jobs)-1].Unmarshal(dAtA[iNdEx:postIndex]); err != nil {
				return err
			}
			iNdEx = postIndex
		default:
			iNdEx = preIndex
			skippy, err := skipCompactorscheduler(dAtA[iNdEx:])
			if err != nil {
				return err
			}
			if (skippy < 0) || (iNdEx+skippy) < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			if (iNdEx + skippy) > l {
				return io.ErrUnexpectedEOF
			}
			iNdEx += skippy
		}
	}

	if iNdEx > l {
		return io.ErrUnexpectedEOF
	}
	return nil
}
func (m *PlannedJobsResponse) Unmarshal(dAtA []byte) error {
	l := len(dAtA)
	iNdEx := 0
	for iNdEx < l {
		preIndex := iNdEx
		var wire uint64
		for shift := uint(0); ; shift += 7 {
			if shift >= 64 {
				return ErrIntOverflowCompactorscheduler
			}
			if iNdEx >= l {
				return io.ErrUnexpectedEOF
			}
			b := dAtA[iNdEx]
			iNdEx++
			wire |= uint64(b&0x7F) << shift
			if b < 0x80 {
				break
			}
		}
		fieldNum := int32(wire >> 3)
		wireType := int(wire & 0x7)
		if wireType == 4 {
			return fmt.Errorf("proto: PlannedJobsResponse: wiretype end group for non-group")
		}
		if fieldNum <= 0 {
			return fmt.Errorf("proto: PlannedJobsResponse: illegal tag %d (wire type %d)", fieldNum, wire)
		}
		switch fieldNum {
		default:
			iNdEx = preIndex
			skippy, err := skipCompactorscheduler(dAtA[iNdEx:])
			if err != nil {
				return err
			}
			if (skippy < 0) || (iNdEx+skippy) < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			if (iNdEx + skippy) > l {
				return io.ErrUnexpectedEOF
			}
			iNdEx += skippy
		}
	}

	if iNdEx > l {
		return io.ErrUnexpectedEOF
	}
	return nil
}
func (m *UpdatePlanJobRequest) Unmarshal(dAtA []byte) error {
	l := len(dAtA)
	iNdEx := 0
	for iNdEx < l {
		preIndex := iNdEx
		var wire uint64
		for shift := uint(0); ; shift += 7 {
			if shift >= 64 {
				return ErrIntOverflowCompactorscheduler
			}
			if iNdEx >= l {
				return io.ErrUnexpectedEOF
			}
			b := dAtA[iNdEx]
			iNdEx++
			wire |= uint64(b&0x7F) << shift
			if b < 0x80 {
				break
			}
		}
		fieldNum := int32(wire >> 3)
		wireType := int(wire & 0x7)
		if wireType == 4 {
			return fmt.Errorf("proto: UpdatePlanJobRequest: wiretype end group for non-group")
		}
		if fieldNum <= 0 {
			return fmt.Errorf("proto: UpdatePlanJobRequest: illegal tag %d (wire type %d)", fieldNum, wire)
		}
		switch fieldNum {
		case 1:
			if wireType != 2 {
				return fmt.Errorf("proto: wrong wireType = %d for field Key", wireType)
			}
			var msglen int
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				msglen |= int(b&0x7F) << shift
				if b < 0x80 {
					break
				}
			}
			if msglen < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			postIndex := iNdEx + msglen
			if postIndex < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			if postIndex > l {
				return io.ErrUnexpectedEOF
			}
			if m.Key == nil {
				m.Key = &JobKey{}
			}
			if err := m.Key.Unmarshal(dAtA[iNdEx:postIndex]); err != nil {
				return err
			}
			iNdEx = postIndex
		case 2:
			if wireType != 2 {
				return fmt.Errorf("proto: wrong wireType = %d for field Tenant", wireType)
			}
			var stringLen uint64
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				stringLen |= uint64(b&0x7F) << shift
				if b < 0x80 {
					break
				}
			}
			intStringLen := int(stringLen)
			if intStringLen < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			postIndex := iNdEx + intStringLen
			if postIndex < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			if postIndex > l {
				return io.ErrUnexpectedEOF
			}
			m.Tenant = string(dAtA[iNdEx:postIndex])
			iNdEx = postIndex
		case 3:
			if wireType != 0 {
				return fmt.Errorf("proto: wrong wireType = %d for field Update", wireType)
			}
			m.Update = 0
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				m.Update |= UpdateType(b&0x7F) << shift
				if b < 0x80 {
					break
				}
			}
		default:
			iNdEx = preIndex
			skippy, err := skipCompactorscheduler(dAtA[iNdEx:])
			if err != nil {
				return err
			}
			if (skippy < 0) || (iNdEx+skippy) < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			if (iNdEx + skippy) > l {
				return io.ErrUnexpectedEOF
			}
			iNdEx += skippy
		}
	}

	if iNdEx > l {
		return io.ErrUnexpectedEOF
	}
	return nil
}
func (m *UpdateCompactionJobRequest) Unmarshal(dAtA []byte) error {
	l := len(dAtA)
	iNdEx := 0
	for iNdEx < l {
		preIndex := iNdEx
		var wire uint64
		for shift := uint(0); ; shift += 7 {
			if shift >= 64 {
				return ErrIntOverflowCompactorscheduler
			}
			if iNdEx >= l {
				return io.ErrUnexpectedEOF
			}
			b := dAtA[iNdEx]
			iNdEx++
			wire |= uint64(b&0x7F) << shift
			if b < 0x80 {
				break
			}
		}
		fieldNum := int32(wire >> 3)
		wireType := int(wire & 0x7)
		if wireType == 4 {
			return fmt.Errorf("proto: UpdateCompactionJobRequest: wiretype end group for non-group")
		}
		if fieldNum <= 0 {
			return fmt.Errorf("proto: UpdateCompactionJobRequest: illegal tag %d (wire type %d)", fieldNum, wire)
		}
		switch fieldNum {
		case 1:
			if wireType != 2 {
				return fmt.Errorf("proto: wrong wireType = %d for field Key", wireType)
			}
			var msglen int
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				msglen |= int(b&0x7F) << shift
				if b < 0x80 {
					break
				}
			}
			if msglen < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			postIndex := iNdEx + msglen
			if postIndex < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			if postIndex > l {
				return io.ErrUnexpectedEOF
			}
			if m.Key == nil {
				m.Key = &JobKey{}
			}
			if err := m.Key.Unmarshal(dAtA[iNdEx:postIndex]); err != nil {
				return err
			}
			iNdEx = postIndex
		case 2:
			if wireType != 2 {
				return fmt.Errorf("proto: wrong wireType = %d for field Tenant", wireType)
			}
			var stringLen uint64
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				stringLen |= uint64(b&0x7F) << shift
				if b < 0x80 {
					break
				}
			}
			intStringLen := int(stringLen)
			if intStringLen < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			postIndex := iNdEx + intStringLen
			if postIndex < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			if postIndex > l {
				return io.ErrUnexpectedEOF
			}
			m.Tenant = string(dAtA[iNdEx:postIndex])
			iNdEx = postIndex
		case 3:
			if wireType != 0 {
				return fmt.Errorf("proto: wrong wireType = %d for field Update", wireType)
			}
			m.Update = 0
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				m.Update |= UpdateType(b&0x7F) << shift
				if b < 0x80 {
					break
				}
			}
		default:
			iNdEx = preIndex
			skippy, err := skipCompactorscheduler(dAtA[iNdEx:])
			if err != nil {
				return err
			}
			if (skippy < 0) || (iNdEx+skippy) < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			if (iNdEx + skippy) > l {
				return io.ErrUnexpectedEOF
			}
			iNdEx += skippy
		}
	}

	if iNdEx > l {
		return io.ErrUnexpectedEOF
	}
	return nil
}
func (m *UpdateJobResponse) Unmarshal(dAtA []byte) error {
	l := len(dAtA)
	iNdEx := 0
	for iNdEx < l {
		preIndex := iNdEx
		var wire uint64
		for shift := uint(0); ; shift += 7 {
			if shift >= 64 {
				return ErrIntOverflowCompactorscheduler
			}
			if iNdEx >= l {
				return io.ErrUnexpectedEOF
			}
			b := dAtA[iNdEx]
			iNdEx++
			wire |= uint64(b&0x7F) << shift
			if b < 0x80 {
				break
			}
		}
		fieldNum := int32(wire >> 3)
		wireType := int(wire & 0x7)
		if wireType == 4 {
			return fmt.Errorf("proto: UpdateJobResponse: wiretype end group for non-group")
		}
		if fieldNum <= 0 {
			return fmt.Errorf("proto: UpdateJobResponse: illegal tag %d (wire type %d)", fieldNum, wire)
		}
		switch fieldNum {
		default:
			iNdEx = preIndex
			skippy, err := skipCompactorscheduler(dAtA[iNdEx:])
			if err != nil {
				return err
			}
			if (skippy < 0) || (iNdEx+skippy) < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			if (iNdEx + skippy) > l {
				return io.ErrUnexpectedEOF
			}
			iNdEx += skippy
		}
	}

	if iNdEx > l {
		return io.ErrUnexpectedEOF
	}
	return nil
}
func (m *StoredJobInfo) Unmarshal(dAtA []byte) error {
	l := len(dAtA)
	iNdEx := 0
	for iNdEx < l {
		preIndex := iNdEx
		var wire uint64
		for shift := uint(0); ; shift += 7 {
			if shift >= 64 {
				return ErrIntOverflowCompactorscheduler
			}
			if iNdEx >= l {
				return io.ErrUnexpectedEOF
			}
			b := dAtA[iNdEx]
			iNdEx++
			wire |= uint64(b&0x7F) << shift
			if b < 0x80 {
				break
			}
		}
		fieldNum := int32(wire >> 3)
		wireType := int(wire & 0x7)
		if wireType == 4 {
			return fmt.Errorf("proto: StoredJobInfo: wiretype end group for non-group")
		}
		if fieldNum <= 0 {
			return fmt.Errorf("proto: StoredJobInfo: illegal tag %d (wire type %d)", fieldNum, wire)
		}
		switch fieldNum {
		case 1:
			if wireType != 0 {
				return fmt.Errorf("proto: wrong wireType = %d for field CreationTime", wireType)
			}
			m.CreationTime = 0
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				m.CreationTime |= int64(b&0x7F) << shift
				if b < 0x80 {
					break
				}
			}
		case 2:
			if wireType != 0 {
				return fmt.Errorf("proto: wrong wireType = %d for field Status", wireType)
			}
			m.Status = 0
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				m.Status |= StoredJobStatus(b&0x7F) << shift
				if b < 0x80 {
					break
				}
			}
		case 3:
			if wireType != 0 {
				return fmt.Errorf("proto: wrong wireType = %d for field StatusTime", wireType)
			}
			m.StatusTime = 0
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				m.StatusTime |= int64(b&0x7F) << shift
				if b < 0x80 {
					break
				}
			}
		case 4:
			if wireType != 0 {
				return fmt.Errorf("proto: wrong wireType = %d for field NumLeases", wireType)
			}
			m.NumLeases = 0
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				m.NumLeases |= int32(b&0x7F) << shift
				if b < 0x80 {
					break
				}
			}
		case 5:
			if wireType != 0 {
				return fmt.Errorf("proto: wrong wireType = %d for field Epoch", wireType)
			}
			m.Epoch = 0
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				m.Epoch |= int64(b&0x7F) << shift
				if b < 0x80 {
					break
				}
			}
		default:
			iNdEx = preIndex
			skippy, err := skipCompactorscheduler(dAtA[iNdEx:])
			if err != nil {
				return err
			}
			if (skippy < 0) || (iNdEx+skippy) < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			if (iNdEx + skippy) > l {
				return io.ErrUnexpectedEOF
			}
			iNdEx += skippy
		}
	}

	if iNdEx > l {
		return io.ErrUnexpectedEOF
	}
	return nil
}
func (m *StoredCompactionJob) Unmarshal(dAtA []byte) error {
	l := len(dAtA)
	iNdEx := 0
	for iNdEx < l {
		preIndex := iNdEx
		var wire uint64
		for shift := uint(0); ; shift += 7 {
			if shift >= 64 {
				return ErrIntOverflowCompactorscheduler
			}
			if iNdEx >= l {
				return io.ErrUnexpectedEOF
			}
			b := dAtA[iNdEx]
			iNdEx++
			wire |= uint64(b&0x7F) << shift
			if b < 0x80 {
				break
			}
		}
		fieldNum := int32(wire >> 3)
		wireType := int(wire & 0x7)
		if wireType == 4 {
			return fmt.Errorf("proto: StoredCompactionJob: wiretype end group for non-group")
		}
		if fieldNum <= 0 {
			return fmt.Errorf("proto: StoredCompactionJob: illegal tag %d (wire type %d)", fieldNum, wire)
		}
		switch fieldNum {
		case 1:
			if wireType != 2 {
				return fmt.Errorf("proto: wrong wireType = %d for field Info", wireType)
			}
			var msglen int
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				msglen |= int(b&0x7F) << shift
				if b < 0x80 {
					break
				}
			}
			if msglen < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			postIndex := iNdEx + msglen
			if postIndex < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			if postIndex > l {
				return io.ErrUnexpectedEOF
			}
			if m.Info == nil {
				m.Info = &StoredJobInfo{}
			}
			if err := m.Info.Unmarshal(dAtA[iNdEx:postIndex]); err != nil {
				return err
			}
			iNdEx = postIndex
		case 2:
			if wireType != 2 {
				return fmt.Errorf("proto: wrong wireType = %d for field Job", wireType)
			}
			var msglen int
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				msglen |= int(b&0x7F) << shift
				if b < 0x80 {
					break
				}
			}
			if msglen < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			postIndex := iNdEx + msglen
			if postIndex < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			if postIndex > l {
				return io.ErrUnexpectedEOF
			}
			if m.Job == nil {
				m.Job = &CompactionJob{}
			}
			if err := m.Job.Unmarshal(dAtA[iNdEx:postIndex]); err != nil {
				return err
			}
			iNdEx = postIndex
		case 3:
			if wireType != 0 {
				return fmt.Errorf("proto: wrong wireType = %d for field Order", wireType)
			}
			m.Order = 0
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				m.Order |= uint32(b&0x7F) << shift
				if b < 0x80 {
					break
				}
			}
		default:
			iNdEx = preIndex
			skippy, err := skipCompactorscheduler(dAtA[iNdEx:])
			if err != nil {
				return err
			}
			if (skippy < 0) || (iNdEx+skippy) < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			if (iNdEx + skippy) > l {
				return io.ErrUnexpectedEOF
			}
			iNdEx += skippy
		}
	}

	if iNdEx > l {
		return io.ErrUnexpectedEOF
	}
	return nil
}
func (m *PersistenceMetadata) Unmarshal(dAtA []byte) error {
	l := len(dAtA)
	iNdEx := 0
	for iNdEx < l {
		preIndex := iNdEx
		var wire uint64
		for shift := uint(0); ; shift += 7 {
			if shift >= 64 {
				return ErrIntOverflowCompactorscheduler
			}
			if iNdEx >= l {
				return io.ErrUnexpectedEOF
			}
			b := dAtA[iNdEx]
			iNdEx++
			wire |= uint64(b&0x7F) << shift
			if b < 0x80 {
				break
			}
		}
		fieldNum := int32(wire >> 3)
		wireType := int(wire & 0x7)
		if wireType == 4 {
			return fmt.Errorf("proto: PersistenceMetadata: wiretype end group for non-group")
		}
		if fieldNum <= 0 {
			return fmt.Errorf("proto: PersistenceMetadata: illegal tag %d (wire type %d)", fieldNum, wire)
		}
		switch fieldNum {
		case 1:
			if wireType != 0 {
				return fmt.Errorf("proto: wrong wireType = %d for field ShardCount", wireType)
			}
			m.ShardCount = 0
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				m.ShardCount |= uint32(b&0x7F) << shift
				if b < 0x80 {
					break
				}
			}
		case 2:
			if wireType != 0 {
				return fmt.Errorf("proto: wrong wireType = %d for field CreationTime", wireType)
			}
			m.CreationTime = 0
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				m.CreationTime |= int64(b&0x7F) << shift
				if b < 0x80 {
					break
				}
			}
		default:
			iNdEx = preIndex
			skippy, err := skipCompactorscheduler(dAtA[iNdEx:])
			if err != nil {
				return err
			}
			if (skippy < 0) || (iNdEx+skippy) < 0 {
				return ErrInvalidLengthCompactorscheduler
			}
			if (iNdEx + skippy) > l {
				return io.ErrUnexpectedEOF
			}
			iNdEx += skippy
		}
	}

	if iNdEx > l {
		return io.ErrUnexpectedEOF
	}
	return nil
}
func skipCompactorscheduler(dAtA []byte) (n int, err error) {
	l := len(dAtA)
	iNdEx := 0
	depth := 0
	for iNdEx < l {
		var wire uint64
		for shift := uint(0); ; shift += 7 {
			if shift >= 64 {
				return 0, ErrIntOverflowCompactorscheduler
			}
			if iNdEx >= l {
				return 0, io.ErrUnexpectedEOF
			}
			b := dAtA[iNdEx]
			iNdEx++
			wire |= (uint64(b) & 0x7F) << shift
			if b < 0x80 {
				break
			}
		}
		wireType := int(wire & 0x7)
		switch wireType {
		case 0:
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return 0, ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return 0, io.ErrUnexpectedEOF
				}
				iNdEx++
				if dAtA[iNdEx-1] < 0x80 {
					break
				}
			}
		case 1:
			iNdEx += 8
		case 2:
			var length int
			for shift := uint(0); ; shift += 7 {
				if shift >= 64 {
					return 0, ErrIntOverflowCompactorscheduler
				}
				if iNdEx >= l {
					return 0, io.ErrUnexpectedEOF
				}
				b := dAtA[iNdEx]
				iNdEx++
				length |= (int(b) & 0x7F) << shift
				if b < 0x80 {
					break
				}
			}
			if length < 0 {
				return 0, ErrInvalidLengthCompactorscheduler
			}
			iNdEx += length
		case 3:
			depth++
		case 4:
			if depth == 0 {
				return 0, ErrUnexpectedEndOfGroupCompactorscheduler
			}
			depth--
		case 5:
			iNdEx += 4
		default:
			return 0, fmt.Errorf("proto: illegal wireType %d", wireType)
		}
		if iNdEx < 0 {
			return 0, ErrInvalidLengthCompactorscheduler
		}
		if depth == 0 {
			return iNdEx, nil
		}
	}
	return 0, io.ErrUnexpectedEOF
}

var (
	ErrInvalidLengthCompactorscheduler        = fmt.Errorf("proto: negative length found during unmarshaling")
	ErrIntOverflowCompactorscheduler          = fmt.Errorf("proto: integer overflow")
	ErrUnexpectedEndOfGroupCompactorscheduler = fmt.Errorf("proto: unexpected end of group")
)
